#  FORK PYROFORK <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

layer = 177

objects = {
    0x05162463: "pyrogram.raw.types.ResPQ",
    0x83c95aec: "pyrogram.raw.types.PQInnerData",
    0xa9f55f95: "pyrogram.raw.types.PQInnerDataDc",
    0x3c6a84d4: "pyrogram.raw.types.PQInnerDataTemp",
    0x56fddf88: "pyrogram.raw.types.PQInnerDataTempDc",
    0x75a3f765: "pyrogram.raw.types.BindAuthKeyInner",
    0x79cb045d: "pyrogram.raw.types.ServerDHParamsFail",
    0xd0e8075c: "pyrogram.raw.types.ServerDHParamsOk",
    0xb5890dba: "pyrogram.raw.types.ServerDHInnerData",
    0x6643b654: "pyrogram.raw.types.ClientDHInnerData",
    0x3bcbf734: "pyrogram.raw.types.DhGenOk",
    0x46dc1fb9: "pyrogram.raw.types.DhGenRetry",
    0xa69dae02: "pyrogram.raw.types.DhGenFail",
    0xf660e1d4: "pyrogram.raw.types.DestroyAuthKeyOk",
    0x0a9f2259: "pyrogram.raw.types.DestroyAuthKeyNone",
    0xea109b13: "pyrogram.raw.types.DestroyAuthKeyFail",
    0x60469778: "pyrogram.raw.functions.ReqPq",
    0xbe7e8ef1: "pyrogram.raw.functions.ReqPqMulti",
    0xd712e4be: "pyrogram.raw.functions.ReqDHParams",
    0xf5045f1f: "pyrogram.raw.functions.SetClientDHParams",
    0xd1435160: "pyrogram.raw.functions.DestroyAuthKey",
    0x62d6b459: "pyrogram.raw.types.MsgsAck",
    0xa7eff811: "pyrogram.raw.types.BadMsgNotification",
    0xedab447b: "pyrogram.raw.types.BadServerSalt",
    0xda69fb52: "pyrogram.raw.types.MsgsStateReq",
    0x04deb57d: "pyrogram.raw.types.MsgsStateInfo",
    0x8cc0d131: "pyrogram.raw.types.MsgsAllInfo",
    0x276d3ec6: "pyrogram.raw.types.MsgDetailedInfo",
    0x809db6df: "pyrogram.raw.types.MsgNewDetailedInfo",
    0x7d861a08: "pyrogram.raw.types.MsgResendReq",
    0x8610baeb: "pyrogram.raw.types.MsgResendAnsReq",
    0xf35c6d01: "pyrogram.raw.types.RpcResult",
    0x2144ca19: "pyrogram.raw.types.RpcError",
    0x5e2ad36e: "pyrogram.raw.types.RpcAnswerUnknown",
    0xcd78e586: "pyrogram.raw.types.RpcAnswerDroppedRunning",
    0xa43ad8b7: "pyrogram.raw.types.RpcAnswerDropped",
    0x347773c5: "pyrogram.raw.types.Pong",
    0xe22045fc: "pyrogram.raw.types.DestroySessionOk",
    0x62d350c9: "pyrogram.raw.types.DestroySessionNone",
    0x9ec20908: "pyrogram.raw.types.NewSessionCreated",
    0x9299359f: "pyrogram.raw.types.HttpWait",
    0xd433ad73: "pyrogram.raw.types.IpPort",
    0x37982646: "pyrogram.raw.types.IpPortSecret",
    0x4679b65f: "pyrogram.raw.types.AccessPointRule",
    0x5a592a6c: "pyrogram.raw.types.help.ConfigSimple",
    0x58e4a740: "pyrogram.raw.functions.RpcDropAnswer",
    0xb921bd04: "pyrogram.raw.functions.GetFutureSalts",
    0x7abe77ec: "pyrogram.raw.functions.Ping",
    0xf3427b8c: "pyrogram.raw.functions.PingDelayDisconnect",
    0xe7512126: "pyrogram.raw.functions.DestroySession",
    0x9a5f6e95: "pyrogram.raw.functions.contest.SaveDeveloperInfo",
    0x7f3b18ea: "pyrogram.raw.types.InputPeerEmpty",
    0x7da07ec9: "pyrogram.raw.types.InputPeerSelf",
    0x35a95cb9: "pyrogram.raw.types.InputPeerChat",
    0xdde8a54c: "pyrogram.raw.types.InputPeerUser",
    0x27bcbbfc: "pyrogram.raw.types.InputPeerChannel",
    0xa87b0a1c: "pyrogram.raw.types.InputPeerUserFromMessage",
    0xbd2a0840: "pyrogram.raw.types.InputPeerChannelFromMessage",
    0xb98886cf: "pyrogram.raw.types.InputUserEmpty",
    0xf7c1b13f: "pyrogram.raw.types.InputUserSelf",
    0xf21158c6: "pyrogram.raw.types.InputUser",
    0x1da448e2: "pyrogram.raw.types.InputUserFromMessage",
    0xf392b7f4: "pyrogram.raw.types.InputPhoneContact",
    0xf52ff27f: "pyrogram.raw.types.InputFile",
    0xfa4f0bb5: "pyrogram.raw.types.InputFileBig",
    0x9664f57f: "pyrogram.raw.types.InputMediaEmpty",
    0x1e287d04: "pyrogram.raw.types.InputMediaUploadedPhoto",
    0xb3ba0635: "pyrogram.raw.types.InputMediaPhoto",
    0xf9c44144: "pyrogram.raw.types.InputMediaGeoPoint",
    0xf8ab7dfb: "pyrogram.raw.types.InputMediaContact",
    0x5b38c6c1: "pyrogram.raw.types.InputMediaUploadedDocument",
    0x33473058: "pyrogram.raw.types.InputMediaDocument",
    0xc13d1c11: "pyrogram.raw.types.InputMediaVenue",
    0xe5bbfe1a: "pyrogram.raw.types.InputMediaPhotoExternal",
    0xfb52dc99: "pyrogram.raw.types.InputMediaDocumentExternal",
    0xd33f43f3: "pyrogram.raw.types.InputMediaGame",
    0x8eb5a6d5: "pyrogram.raw.types.InputMediaInvoice",
    0x971fa843: "pyrogram.raw.types.InputMediaGeoLive",
    0xf94e5f1: "pyrogram.raw.types.InputMediaPoll",
    0xe66fbf7b: "pyrogram.raw.types.InputMediaDice",
    0x89fdd778: "pyrogram.raw.types.InputMediaStory",
    0xc21b8849: "pyrogram.raw.types.InputMediaWebPage",
    0x1ca48f57: "pyrogram.raw.types.InputChatPhotoEmpty",
    0xbdcdaec0: "pyrogram.raw.types.InputChatUploadedPhoto",
    0x8953ad37: "pyrogram.raw.types.InputChatPhoto",
    0xe4c123d6: "pyrogram.raw.types.InputGeoPointEmpty",
    0x48222faf: "pyrogram.raw.types.InputGeoPoint",
    0x1cd7bf0d: "pyrogram.raw.types.InputPhotoEmpty",
    0x3bb3b94a: "pyrogram.raw.types.InputPhoto",
    0xdfdaabe1: "pyrogram.raw.types.InputFileLocation",
    0xf5235d55: "pyrogram.raw.types.InputEncryptedFileLocation",
    0xbad07584: "pyrogram.raw.types.InputDocumentFileLocation",
    0xcbc7ee28: "pyrogram.raw.types.InputSecureFileLocation",
    0x29be5899: "pyrogram.raw.types.InputTakeoutFileLocation",
    0x40181ffe: "pyrogram.raw.types.InputPhotoFileLocation",
    0xd83466f3: "pyrogram.raw.types.InputPhotoLegacyFileLocation",
    0x37257e99: "pyrogram.raw.types.InputPeerPhotoFileLocation",
    0x9d84f3db: "pyrogram.raw.types.InputStickerSetThumb",
    0x598a92a: "pyrogram.raw.types.InputGroupCallStream",
    0x59511722: "pyrogram.raw.types.PeerUser",
    0x36c6019a: "pyrogram.raw.types.PeerChat",
    0xa2a5371e: "pyrogram.raw.types.PeerChannel",
    0xaa963b05: "pyrogram.raw.types.storage.FileUnknown",
    0x40bc6f52: "pyrogram.raw.types.storage.FilePartial",
    0x7efe0e: "pyrogram.raw.types.storage.FileJpeg",
    0xcae1aadf: "pyrogram.raw.types.storage.FileGif",
    0xa4f63c0: "pyrogram.raw.types.storage.FilePng",
    0xae1e508d: "pyrogram.raw.types.storage.FilePdf",
    0x528a0677: "pyrogram.raw.types.storage.FileMp3",
    0x4b09ebbc: "pyrogram.raw.types.storage.FileMov",
    0xb3cea0e4: "pyrogram.raw.types.storage.FileMp4",
    0x1081464c: "pyrogram.raw.types.storage.FileWebp",
    0xd3bc4b7a: "pyrogram.raw.types.UserEmpty",
    0x215c4438: "pyrogram.raw.types.User",
    0x4f11bae1: "pyrogram.raw.types.UserProfilePhotoEmpty",
    0x82d1f706: "pyrogram.raw.types.UserProfilePhoto",
    0x9d05049: "pyrogram.raw.types.UserStatusEmpty",
    0xedb93949: "pyrogram.raw.types.UserStatusOnline",
    0x8c703f: "pyrogram.raw.types.UserStatusOffline",
    0x7b197dc8: "pyrogram.raw.types.UserStatusRecently",
    0x541a1d1a: "pyrogram.raw.types.UserStatusLastWeek",
    0x65899777: "pyrogram.raw.types.UserStatusLastMonth",
    0x29562865: "pyrogram.raw.types.ChatEmpty",
    0x41cbf256: "pyrogram.raw.types.Chat",
    0x6592a1a7: "pyrogram.raw.types.ChatForbidden",
    0xaadfc8f: "pyrogram.raw.types.Channel",
    0x17d493d5: "pyrogram.raw.types.ChannelForbidden",
    0xc9d31138: "pyrogram.raw.types.ChatFull",
    0x44c054a7: "pyrogram.raw.types.ChannelFull",
    0xc02d4007: "pyrogram.raw.types.ChatParticipant",
    0xe46bcee4: "pyrogram.raw.types.ChatParticipantCreator",
    0xa0933f5b: "pyrogram.raw.types.ChatParticipantAdmin",
    0x8763d3e1: "pyrogram.raw.types.ChatParticipantsForbidden",
    0x3cbc93f8: "pyrogram.raw.types.ChatParticipants",
    0x37c1011c: "pyrogram.raw.types.ChatPhotoEmpty",
    0x1c6e1c11: "pyrogram.raw.types.ChatPhoto",
    0x90a6ca84: "pyrogram.raw.types.MessageEmpty",
    0x2357bf25: "pyrogram.raw.types.Message",
    0x2b085862: "pyrogram.raw.types.MessageService",
    0x3ded6320: "pyrogram.raw.types.MessageMediaEmpty",
    0x695150d7: "pyrogram.raw.types.MessageMediaPhoto",
    0x56e0d474: "pyrogram.raw.types.MessageMediaGeo",
    0x70322949: "pyrogram.raw.types.MessageMediaContact",
    0x9f84f49e: "pyrogram.raw.types.MessageMediaUnsupported",
    0x4cf4d72d: "pyrogram.raw.types.MessageMediaDocument",
    0xddf10c3b: "pyrogram.raw.types.MessageMediaWebPage",
    0x2ec0533f: "pyrogram.raw.types.MessageMediaVenue",
    0xfdb19008: "pyrogram.raw.types.MessageMediaGame",
    0xf6a548d3: "pyrogram.raw.types.MessageMediaInvoice",
    0xb940c666: "pyrogram.raw.types.MessageMediaGeoLive",
    0x4bd6e798: "pyrogram.raw.types.MessageMediaPoll",
    0x3f7ee58b: "pyrogram.raw.types.MessageMediaDice",
    0x68cb6283: "pyrogram.raw.types.MessageMediaStory",
    0xdaad85b0: "pyrogram.raw.types.MessageMediaGiveaway",
    0xc6991068: "pyrogram.raw.types.MessageMediaGiveawayResults",
    0xb6aef7b0: "pyrogram.raw.types.MessageActionEmpty",
    0xbd47cbad: "pyrogram.raw.types.MessageActionChatCreate",
    0xb5a1ce5a: "pyrogram.raw.types.MessageActionChatEditTitle",
    0x7fcb13a8: "pyrogram.raw.types.MessageActionChatEditPhoto",
    0x95e3fbef: "pyrogram.raw.types.MessageActionChatDeletePhoto",
    0x15cefd00: "pyrogram.raw.types.MessageActionChatAddUser",
    0xa43f30cc: "pyrogram.raw.types.MessageActionChatDeleteUser",
    0x31224c3: "pyrogram.raw.types.MessageActionChatJoinedByLink",
    0x95d2ac92: "pyrogram.raw.types.MessageActionChannelCreate",
    0xe1037f92: "pyrogram.raw.types.MessageActionChatMigrateTo",
    0xea3948e9: "pyrogram.raw.types.MessageActionChannelMigrateFrom",
    0x94bd38ed: "pyrogram.raw.types.MessageActionPinMessage",
    0x9fbab604: "pyrogram.raw.types.MessageActionHistoryClear",
    0x92a72876: "pyrogram.raw.types.MessageActionGameScore",
    0x8f31b327: "pyrogram.raw.types.MessageActionPaymentSentMe",
    0x96163f56: "pyrogram.raw.types.MessageActionPaymentSent",
    0x80e11a7f: "pyrogram.raw.types.MessageActionPhoneCall",
    0x4792929b: "pyrogram.raw.types.MessageActionScreenshotTaken",
    0xfae69f56: "pyrogram.raw.types.MessageActionCustomAction",
    0xc516d679: "pyrogram.raw.types.MessageActionBotAllowed",
    0x1b287353: "pyrogram.raw.types.MessageActionSecureValuesSentMe",
    0xd95c6154: "pyrogram.raw.types.MessageActionSecureValuesSent",
    0xf3f25f76: "pyrogram.raw.types.MessageActionContactSignUp",
    0x98e0d697: "pyrogram.raw.types.MessageActionGeoProximityReached",
    0x7a0d7f42: "pyrogram.raw.types.MessageActionGroupCall",
    0x502f92f7: "pyrogram.raw.types.MessageActionInviteToGroupCall",
    0x3c134d7b: "pyrogram.raw.types.MessageActionSetMessagesTTL",
    0xb3a07661: "pyrogram.raw.types.MessageActionGroupCallScheduled",
    0xaa786345: "pyrogram.raw.types.MessageActionSetChatTheme",
    0xebbca3cb: "pyrogram.raw.types.MessageActionChatJoinedByRequest",
    0x47dd8079: "pyrogram.raw.types.MessageActionWebViewDataSentMe",
    0xb4c38cb5: "pyrogram.raw.types.MessageActionWebViewDataSent",
    0xc83d6aec: "pyrogram.raw.types.MessageActionGiftPremium",
    0xd999256: "pyrogram.raw.types.MessageActionTopicCreate",
    0xc0944820: "pyrogram.raw.types.MessageActionTopicEdit",
    0x57de635e: "pyrogram.raw.types.MessageActionSuggestProfilePhoto",
    0x31518e9b: "pyrogram.raw.types.MessageActionRequestedPeer",
    0x5060a3f4: "pyrogram.raw.types.MessageActionSetChatWallPaper",
    0x678c2e09: "pyrogram.raw.types.MessageActionGiftCode",
    0x332ba9ed: "pyrogram.raw.types.MessageActionGiveawayLaunch",
    0x2a9fadc5: "pyrogram.raw.types.MessageActionGiveawayResults",
    0xcc02aa6d: "pyrogram.raw.types.MessageActionBoostApply",
    0x93b31848: "pyrogram.raw.types.MessageActionRequestedPeerSentMe",
    0xd58a08c6: "pyrogram.raw.types.Dialog",
    0x71bd134c: "pyrogram.raw.types.DialogFolder",
    0x2331b22d: "pyrogram.raw.types.PhotoEmpty",
    0xfb197a65: "pyrogram.raw.types.Photo",
    0xe17e23c: "pyrogram.raw.types.PhotoSizeEmpty",
    0x75c78e60: "pyrogram.raw.types.PhotoSize",
    0x21e1ad6: "pyrogram.raw.types.PhotoCachedSize",
    0xe0b0bc2e: "pyrogram.raw.types.PhotoStrippedSize",
    0xfa3efb95: "pyrogram.raw.types.PhotoSizeProgressive",
    0xd8214d41: "pyrogram.raw.types.PhotoPathSize",
    0x1117dd5f: "pyrogram.raw.types.GeoPointEmpty",
    0xb2a2f663: "pyrogram.raw.types.GeoPoint",
    0x5e002502: "pyrogram.raw.types.auth.SentCode",
    0x2390fe44: "pyrogram.raw.types.auth.SentCodeSuccess",
    0x2ea2c0d4: "pyrogram.raw.types.auth.Authorization",
    0x44747e9a: "pyrogram.raw.types.auth.AuthorizationSignUpRequired",
    0xb434e2b8: "pyrogram.raw.types.auth.ExportedAuthorization",
    0xb8bc5b0c: "pyrogram.raw.types.InputNotifyPeer",
    0x193b4417: "pyrogram.raw.types.InputNotifyUsers",
    0x4a95e84e: "pyrogram.raw.types.InputNotifyChats",
    0xb1db7c7e: "pyrogram.raw.types.InputNotifyBroadcasts",
    0x5c467992: "pyrogram.raw.types.InputNotifyForumTopic",
    0xcacb6ae2: "pyrogram.raw.types.InputPeerNotifySettings",
    0x99622c0c: "pyrogram.raw.types.PeerNotifySettings",
    0xacd66c5e: "pyrogram.raw.types.PeerSettings",
    0xa437c3ed: "pyrogram.raw.types.WallPaper",
    0xe0804116: "pyrogram.raw.types.WallPaperNoFile",
    0x58dbcab8: "pyrogram.raw.types.InputReportReasonSpam",
    0x1e22c78d: "pyrogram.raw.types.InputReportReasonViolence",
    0x2e59d922: "pyrogram.raw.types.InputReportReasonPornography",
    0xadf44ee3: "pyrogram.raw.types.InputReportReasonChildAbuse",
    0xc1e4a2b1: "pyrogram.raw.types.InputReportReasonOther",
    0x9b89f93a: "pyrogram.raw.types.InputReportReasonCopyright",
    0xdbd4feed: "pyrogram.raw.types.InputReportReasonGeoIrrelevant",
    0xf5ddd6e7: "pyrogram.raw.types.InputReportReasonFake",
    0xa8eb2be: "pyrogram.raw.types.InputReportReasonIllegalDrugs",
    0x9ec7863d: "pyrogram.raw.types.InputReportReasonPersonalDetails",
    0xcc997720: "pyrogram.raw.types.UserFull",
    0x145ade0b: "pyrogram.raw.types.Contact",
    0xc13e3c50: "pyrogram.raw.types.ImportedContact",
    0x16d9703b: "pyrogram.raw.types.ContactStatus",
    0xb74ba9d2: "pyrogram.raw.types.contacts.ContactsNotModified",
    0xeae87e42: "pyrogram.raw.types.contacts.Contacts",
    0x77d01c3b: "pyrogram.raw.types.contacts.ImportedContacts",
    0xade1591: "pyrogram.raw.types.contacts.Blocked",
    0xe1664194: "pyrogram.raw.types.contacts.BlockedSlice",
    0x15ba6c40: "pyrogram.raw.types.messages.Dialogs",
    0x71e094f3: "pyrogram.raw.types.messages.DialogsSlice",
    0xf0e3e596: "pyrogram.raw.types.messages.DialogsNotModified",
    0x8c718e87: "pyrogram.raw.types.messages.Messages",
    0x3a54685e: "pyrogram.raw.types.messages.MessagesSlice",
    0xc776ba4e: "pyrogram.raw.types.messages.ChannelMessages",
    0x74535f21: "pyrogram.raw.types.messages.MessagesNotModified",
    0x64ff9fd5: "pyrogram.raw.types.messages.Chats",
    0x9cd81144: "pyrogram.raw.types.messages.ChatsSlice",
    0xe5d7d19c: "pyrogram.raw.types.messages.ChatFull",
    0xb45c69d1: "pyrogram.raw.types.messages.AffectedHistory",
    0x57e2f66c: "pyrogram.raw.types.InputMessagesFilterEmpty",
    0x9609a51c: "pyrogram.raw.types.InputMessagesFilterPhotos",
    0x9fc00e65: "pyrogram.raw.types.InputMessagesFilterVideo",
    0x56e9f0e4: "pyrogram.raw.types.InputMessagesFilterPhotoVideo",
    0x9eddf188: "pyrogram.raw.types.InputMessagesFilterDocument",
    0x7ef0dd87: "pyrogram.raw.types.InputMessagesFilterUrl",
    0xffc86587: "pyrogram.raw.types.InputMessagesFilterGif",
    0x50f5c392: "pyrogram.raw.types.InputMessagesFilterVoice",
    0x3751b49e: "pyrogram.raw.types.InputMessagesFilterMusic",
    0x3a20ecb8: "pyrogram.raw.types.InputMessagesFilterChatPhotos",
    0x80c99768: "pyrogram.raw.types.InputMessagesFilterPhoneCalls",
    0x7a7c17a4: "pyrogram.raw.types.InputMessagesFilterRoundVoice",
    0xb549da53: "pyrogram.raw.types.InputMessagesFilterRoundVideo",
    0xc1f8e69a: "pyrogram.raw.types.InputMessagesFilterMyMentions",
    0xe7026d0d: "pyrogram.raw.types.InputMessagesFilterGeo",
    0xe062db83: "pyrogram.raw.types.InputMessagesFilterContacts",
    0x1bb00451: "pyrogram.raw.types.InputMessagesFilterPinned",
    0x1f2b0afd: "pyrogram.raw.types.UpdateNewMessage",
    0x4e90bfd6: "pyrogram.raw.types.UpdateMessageID",
    0xa20db0e5: "pyrogram.raw.types.UpdateDeleteMessages",
    0xc01e857f: "pyrogram.raw.types.UpdateUserTyping",
    0x83487af0: "pyrogram.raw.types.UpdateChatUserTyping",
    0x7761198: "pyrogram.raw.types.UpdateChatParticipants",
    0xe5bdf8de: "pyrogram.raw.types.UpdateUserStatus",
    0xa7848924: "pyrogram.raw.types.UpdateUserName",
    0x8951abef: "pyrogram.raw.types.UpdateNewAuthorization",
    0x12bcbd9a: "pyrogram.raw.types.UpdateNewEncryptedMessage",
    0x1710f156: "pyrogram.raw.types.UpdateEncryptedChatTyping",
    0xb4a2e88d: "pyrogram.raw.types.UpdateEncryption",
    0x38fe25b7: "pyrogram.raw.types.UpdateEncryptedMessagesRead",
    0x3dda5451: "pyrogram.raw.types.UpdateChatParticipantAdd",
    0xe32f3d77: "pyrogram.raw.types.UpdateChatParticipantDelete",
    0x8e5e9873: "pyrogram.raw.types.UpdateDcOptions",
    0xbec268ef: "pyrogram.raw.types.UpdateNotifySettings",
    0xebe46819: "pyrogram.raw.types.UpdateServiceNotification",
    0xee3b272a: "pyrogram.raw.types.UpdatePrivacy",
    0x5492a13: "pyrogram.raw.types.UpdateUserPhone",
    0x9c974fdf: "pyrogram.raw.types.UpdateReadHistoryInbox",
    0x2f2f21bf: "pyrogram.raw.types.UpdateReadHistoryOutbox",
    0x7f891213: "pyrogram.raw.types.UpdateWebPage",
    0xf8227181: "pyrogram.raw.types.UpdateReadMessagesContents",
    0x108d941f: "pyrogram.raw.types.UpdateChannelTooLong",
    0x635b4c09: "pyrogram.raw.types.UpdateChannel",
    0x62ba04d9: "pyrogram.raw.types.UpdateNewChannelMessage",
    0x922e6e10: "pyrogram.raw.types.UpdateReadChannelInbox",
    0xc32d5b12: "pyrogram.raw.types.UpdateDeleteChannelMessages",
    0xf226ac08: "pyrogram.raw.types.UpdateChannelMessageViews",
    0xd7ca61a2: "pyrogram.raw.types.UpdateChatParticipantAdmin",
    0x688a30aa: "pyrogram.raw.types.UpdateNewStickerSet",
    0xbb2d201: "pyrogram.raw.types.UpdateStickerSetsOrder",
    0x31c24808: "pyrogram.raw.types.UpdateStickerSets",
    0x9375341e: "pyrogram.raw.types.UpdateSavedGifs",
    0x496f379c: "pyrogram.raw.types.UpdateBotInlineQuery",
    0x12f12a07: "pyrogram.raw.types.UpdateBotInlineSend",
    0x1b3f4df7: "pyrogram.raw.types.UpdateEditChannelMessage",
    0xb9cfc48d: "pyrogram.raw.types.UpdateBotCallbackQuery",
    0xe40370a3: "pyrogram.raw.types.UpdateEditMessage",
    0x691e9052: "pyrogram.raw.types.UpdateInlineBotCallbackQuery",
    0xb75f99a9: "pyrogram.raw.types.UpdateReadChannelOutbox",
    0x1b49ec6d: "pyrogram.raw.types.UpdateDraftMessage",
    0x571d2742: "pyrogram.raw.types.UpdateReadFeaturedStickers",
    0x9a422c20: "pyrogram.raw.types.UpdateRecentStickers",
    0xa229dd06: "pyrogram.raw.types.UpdateConfig",
    0x3354678f: "pyrogram.raw.types.UpdatePtsChanged",
    0x2f2ba99f: "pyrogram.raw.types.UpdateChannelWebPage",
    0x6e6fe51c: "pyrogram.raw.types.UpdateDialogPinned",
    0xfa0f3ca2: "pyrogram.raw.types.UpdatePinnedDialogs",
    0x8317c0c3: "pyrogram.raw.types.UpdateBotWebhookJSON",
    0x9b9240a6: "pyrogram.raw.types.UpdateBotWebhookJSONQuery",
    0xb5aefd7d: "pyrogram.raw.types.UpdateBotShippingQuery",
    0x8caa9a96: "pyrogram.raw.types.UpdateBotPrecheckoutQuery",
    0xab0f6b1e: "pyrogram.raw.types.UpdatePhoneCall",
    0x46560264: "pyrogram.raw.types.UpdateLangPackTooLong",
    0x56022f4d: "pyrogram.raw.types.UpdateLangPack",
    0xe511996d: "pyrogram.raw.types.UpdateFavedStickers",
    0xea29055d: "pyrogram.raw.types.UpdateChannelReadMessagesContents",
    0x7084a7be: "pyrogram.raw.types.UpdateContactsReset",
    0xb23fc698: "pyrogram.raw.types.UpdateChannelAvailableMessages",
    0xe16459c3: "pyrogram.raw.types.UpdateDialogUnreadMark",
    0xaca1657b: "pyrogram.raw.types.UpdateMessagePoll",
    0x54c01850: "pyrogram.raw.types.UpdateChatDefaultBannedRights",
    0x19360dc0: "pyrogram.raw.types.UpdateFolderPeers",
    0x6a7e7366: "pyrogram.raw.types.UpdatePeerSettings",
    0xb4afcfb0: "pyrogram.raw.types.UpdatePeerLocated",
    0x39a51dfb: "pyrogram.raw.types.UpdateNewScheduledMessage",
    0x90866cee: "pyrogram.raw.types.UpdateDeleteScheduledMessages",
    0x8216fba3: "pyrogram.raw.types.UpdateTheme",
    0x871fb939: "pyrogram.raw.types.UpdateGeoLiveViewed",
    0x564fe691: "pyrogram.raw.types.UpdateLoginToken",
    0x24f40e77: "pyrogram.raw.types.UpdateMessagePollVote",
    0x26ffde7d: "pyrogram.raw.types.UpdateDialogFilter",
    0xa5d72105: "pyrogram.raw.types.UpdateDialogFilterOrder",
    0x3504914f: "pyrogram.raw.types.UpdateDialogFilters",
    0x2661bf09: "pyrogram.raw.types.UpdatePhoneCallSignalingData",
    0xd29a27f4: "pyrogram.raw.types.UpdateChannelMessageForwards",
    0xd6b19546: "pyrogram.raw.types.UpdateReadChannelDiscussionInbox",
    0x695c9e7c: "pyrogram.raw.types.UpdateReadChannelDiscussionOutbox",
    0xebe07752: "pyrogram.raw.types.UpdatePeerBlocked",
    0x8c88c923: "pyrogram.raw.types.UpdateChannelUserTyping",
    0xed85eab5: "pyrogram.raw.types.UpdatePinnedMessages",
    0x5bb98608: "pyrogram.raw.types.UpdatePinnedChannelMessages",
    0xf89a6a4e: "pyrogram.raw.types.UpdateChat",
    0xf2ebdb4e: "pyrogram.raw.types.UpdateGroupCallParticipants",
    0x14b24500: "pyrogram.raw.types.UpdateGroupCall",
    0xbb9bb9a5: "pyrogram.raw.types.UpdatePeerHistoryTTL",
    0xd087663a: "pyrogram.raw.types.UpdateChatParticipant",
    0x985d3abb: "pyrogram.raw.types.UpdateChannelParticipant",
    0xc4870a49: "pyrogram.raw.types.UpdateBotStopped",
    0xb783982: "pyrogram.raw.types.UpdateGroupCallConnection",
    0x4d712f2e: "pyrogram.raw.types.UpdateBotCommands",
    0x7063c3db: "pyrogram.raw.types.UpdatePendingJoinRequests",
    0x11dfa986: "pyrogram.raw.types.UpdateBotChatInviteRequester",
    0x5e1b3cb8: "pyrogram.raw.types.UpdateMessageReactions",
    0x17b7a20b: "pyrogram.raw.types.UpdateAttachMenuBots",
    0x1592b79d: "pyrogram.raw.types.UpdateWebViewResultSent",
    0x14b85813: "pyrogram.raw.types.UpdateBotMenuButton",
    0x74d8be99: "pyrogram.raw.types.UpdateSavedRingtones",
    0x84cd5a: "pyrogram.raw.types.UpdateTranscribedAudio",
    0xfb4c496c: "pyrogram.raw.types.UpdateReadFeaturedEmojiStickers",
    0x28373599: "pyrogram.raw.types.UpdateUserEmojiStatus",
    0x30f443db: "pyrogram.raw.types.UpdateRecentEmojiStatuses",
    0x6f7863f4: "pyrogram.raw.types.UpdateRecentReactions",
    0x86fccf85: "pyrogram.raw.types.UpdateMoveStickerSetToTop",
    0x5a73a98c: "pyrogram.raw.types.UpdateMessageExtendedMedia",
    0x192efbe3: "pyrogram.raw.types.UpdateChannelPinnedTopic",
    0xfe198602: "pyrogram.raw.types.UpdateChannelPinnedTopics",
    0x20529438: "pyrogram.raw.types.UpdateUser",
    0xec05b097: "pyrogram.raw.types.UpdateAutoSaveSettings",
    0x75b3b798: "pyrogram.raw.types.UpdateStory",
    0xf74e932b: "pyrogram.raw.types.UpdateReadStories",
    0x1bf335b9: "pyrogram.raw.types.UpdateStoryID",
    0x2c084dc1: "pyrogram.raw.types.UpdateStoriesStealthMode",
    0x7d627683: "pyrogram.raw.types.UpdateSentStoryReaction",
    0x904dd49c: "pyrogram.raw.types.UpdateBotChatBoost",
    0x7b68920: "pyrogram.raw.types.UpdateChannelViewForumAsMessages",
    0xae3f101d: "pyrogram.raw.types.UpdatePeerWallpaper",
    0xac21d3ce: "pyrogram.raw.types.UpdateBotMessageReaction",
    0x9cb7759: "pyrogram.raw.types.UpdateBotMessageReactions",
    0xaeaf9e74: "pyrogram.raw.types.UpdateSavedDialogPinned",
    0x686c85a6: "pyrogram.raw.types.UpdatePinnedSavedDialogs",
    0x39c67432: "pyrogram.raw.types.UpdateSavedReactionTags",
    0xf16269d4: "pyrogram.raw.types.UpdateSmsJob",
    0xf9470ab2: "pyrogram.raw.types.UpdateQuickReplies",
    0xf53da717: "pyrogram.raw.types.UpdateNewQuickReply",
    0x53e6f1ec: "pyrogram.raw.types.UpdateDeleteQuickReply",
    0x3e050d0f: "pyrogram.raw.types.UpdateQuickReplyMessage",
    0x566fe7cd: "pyrogram.raw.types.UpdateDeleteQuickReplyMessages",
    0x8ae5c97a: "pyrogram.raw.types.UpdateBotBusinessConnect",
    0x9ddb347c: "pyrogram.raw.types.UpdateBotNewBusinessMessage",
    0x7df587c: "pyrogram.raw.types.UpdateBotEditBusinessMessage",
    0xa02a982e: "pyrogram.raw.types.UpdateBotDeleteBusinessMessage",
    0xa56c2a3e: "pyrogram.raw.types.updates.State",
    0x5d75a138: "pyrogram.raw.types.updates.DifferenceEmpty",
    0xf49ca0: "pyrogram.raw.types.updates.Difference",
    0xa8fb1981: "pyrogram.raw.types.updates.DifferenceSlice",
    0x4afe8f6d: "pyrogram.raw.types.updates.DifferenceTooLong",
    0xe317af7e: "pyrogram.raw.types.UpdatesTooLong",
    0x313bc7f8: "pyrogram.raw.types.UpdateShortMessage",
    0x4d6deea5: "pyrogram.raw.types.UpdateShortChatMessage",
    0x78d4dec1: "pyrogram.raw.types.UpdateShort",
    0x725b04c3: "pyrogram.raw.types.UpdatesCombined",
    0x74ae4240: "pyrogram.raw.types.Updates",
    0x9015e101: "pyrogram.raw.types.UpdateShortSentMessage",
    0x8dca6aa5: "pyrogram.raw.types.photos.Photos",
    0x15051f54: "pyrogram.raw.types.photos.PhotosSlice",
    0x20212ca8: "pyrogram.raw.types.photos.Photo",
    0x96a18d5: "pyrogram.raw.types.upload.File",
    0xf18cda44: "pyrogram.raw.types.upload.FileCdnRedirect",
    0x18b7a10d: "pyrogram.raw.types.DcOption",
    0xcc1a241e: "pyrogram.raw.types.Config",
    0x8e1a1775: "pyrogram.raw.types.NearestDc",
    0xccbbce30: "pyrogram.raw.types.help.AppUpdate",
    0xc45a6536: "pyrogram.raw.types.help.NoAppUpdate",
    0x18cb9f78: "pyrogram.raw.types.help.InviteText",
    0xab7ec0a0: "pyrogram.raw.types.EncryptedChatEmpty",
    0x66b25953: "pyrogram.raw.types.EncryptedChatWaiting",
    0x48f1d94c: "pyrogram.raw.types.EncryptedChatRequested",
    0x61f0d4c7: "pyrogram.raw.types.EncryptedChat",
    0x1e1c7c45: "pyrogram.raw.types.EncryptedChatDiscarded",
    0xf141b5e1: "pyrogram.raw.types.InputEncryptedChat",
    0xc21f497e: "pyrogram.raw.types.EncryptedFileEmpty",
    0xa8008cd8: "pyrogram.raw.types.EncryptedFile",
    0x1837c364: "pyrogram.raw.types.InputEncryptedFileEmpty",
    0x64bd0306: "pyrogram.raw.types.InputEncryptedFileUploaded",
    0x5a17b5e5: "pyrogram.raw.types.InputEncryptedFile",
    0x2dc173c8: "pyrogram.raw.types.InputEncryptedFileBigUploaded",
    0xed18c118: "pyrogram.raw.types.EncryptedMessage",
    0x23734b06: "pyrogram.raw.types.EncryptedMessageService",
    0xc0e24635: "pyrogram.raw.types.messages.DhConfigNotModified",
    0x2c221edd: "pyrogram.raw.types.messages.DhConfig",
    0x560f8935: "pyrogram.raw.types.messages.SentEncryptedMessage",
    0x9493ff32: "pyrogram.raw.types.messages.SentEncryptedFile",
    0x72f0eaae: "pyrogram.raw.types.InputDocumentEmpty",
    0x1abfb575: "pyrogram.raw.types.InputDocument",
    0x36f8c871: "pyrogram.raw.types.DocumentEmpty",
    0x8fd4c4d8: "pyrogram.raw.types.Document",
    0x17c6b5f6: "pyrogram.raw.types.help.Support",
    0x9fd40bd8: "pyrogram.raw.types.NotifyPeer",
    0xb4c83b4c: "pyrogram.raw.types.NotifyUsers",
    0xc007cec3: "pyrogram.raw.types.NotifyChats",
    0xd612e8ef: "pyrogram.raw.types.NotifyBroadcasts",
    0x226e6308: "pyrogram.raw.types.NotifyForumTopic",
    0x16bf744e: "pyrogram.raw.types.SendMessageTypingAction",
    0xfd5ec8f5: "pyrogram.raw.types.SendMessageCancelAction",
    0xa187d66f: "pyrogram.raw.types.SendMessageRecordVideoAction",
    0xe9763aec: "pyrogram.raw.types.SendMessageUploadVideoAction",
    0xd52f73f7: "pyrogram.raw.types.SendMessageRecordAudioAction",
    0xf351d7ab: "pyrogram.raw.types.SendMessageUploadAudioAction",
    0xd1d34a26: "pyrogram.raw.types.SendMessageUploadPhotoAction",
    0xaa0cd9e4: "pyrogram.raw.types.SendMessageUploadDocumentAction",
    0x176f8ba1: "pyrogram.raw.types.SendMessageGeoLocationAction",
    0x628cbc6f: "pyrogram.raw.types.SendMessageChooseContactAction",
    0xdd6a8f48: "pyrogram.raw.types.SendMessageGamePlayAction",
    0x88f27fbc: "pyrogram.raw.types.SendMessageRecordRoundAction",
    0x243e1c66: "pyrogram.raw.types.SendMessageUploadRoundAction",
    0xd92c2285: "pyrogram.raw.types.SpeakingInGroupCallAction",
    0xdbda9246: "pyrogram.raw.types.SendMessageHistoryImportAction",
    0xb05ac6b1: "pyrogram.raw.types.SendMessageChooseStickerAction",
    0x25972bcb: "pyrogram.raw.types.SendMessageEmojiInteraction",
    0xb665902e: "pyrogram.raw.types.SendMessageEmojiInteractionSeen",
    0xb3134d9d: "pyrogram.raw.types.contacts.Found",
    0x4f96cb18: "pyrogram.raw.types.InputPrivacyKeyStatusTimestamp",
    0xbdfb0426: "pyrogram.raw.types.InputPrivacyKeyChatInvite",
    0xfabadc5f: "pyrogram.raw.types.InputPrivacyKeyPhoneCall",
    0xdb9e70d2: "pyrogram.raw.types.InputPrivacyKeyPhoneP2P",
    0xa4dd4c08: "pyrogram.raw.types.InputPrivacyKeyForwards",
    0x5719bacc: "pyrogram.raw.types.InputPrivacyKeyProfilePhoto",
    0x352dafa: "pyrogram.raw.types.InputPrivacyKeyPhoneNumber",
    0xd1219bdd: "pyrogram.raw.types.InputPrivacyKeyAddedByPhone",
    0xaee69d68: "pyrogram.raw.types.InputPrivacyKeyVoiceMessages",
    0x3823cc40: "pyrogram.raw.types.InputPrivacyKeyAbout",
    0xd65a11cc: "pyrogram.raw.types.InputPrivacyKeyBirthday",
    0xbc2eab30: "pyrogram.raw.types.PrivacyKeyStatusTimestamp",
    0x500e6dfa: "pyrogram.raw.types.PrivacyKeyChatInvite",
    0x3d662b7b: "pyrogram.raw.types.PrivacyKeyPhoneCall",
    0x39491cc8: "pyrogram.raw.types.PrivacyKeyPhoneP2P",
    0x69ec56a3: "pyrogram.raw.types.PrivacyKeyForwards",
    0x96151fed: "pyrogram.raw.types.PrivacyKeyProfilePhoto",
    0xd19ae46d: "pyrogram.raw.types.PrivacyKeyPhoneNumber",
    0x42ffd42b: "pyrogram.raw.types.PrivacyKeyAddedByPhone",
    0x697f414: "pyrogram.raw.types.PrivacyKeyVoiceMessages",
    0xa486b761: "pyrogram.raw.types.PrivacyKeyAbout",
    0x2000a518: "pyrogram.raw.types.PrivacyKeyBirthday",
    0xd09e07b: "pyrogram.raw.types.InputPrivacyValueAllowContacts",
    0x184b35ce: "pyrogram.raw.types.InputPrivacyValueAllowAll",
    0x131cc67f: "pyrogram.raw.types.InputPrivacyValueAllowUsers",
    0xba52007: "pyrogram.raw.types.InputPrivacyValueDisallowContacts",
    0xd66b66c9: "pyrogram.raw.types.InputPrivacyValueDisallowAll",
    0x90110467: "pyrogram.raw.types.InputPrivacyValueDisallowUsers",
    0x840649cf: "pyrogram.raw.types.InputPrivacyValueAllowChatParticipants",
    0xe94f0f86: "pyrogram.raw.types.InputPrivacyValueDisallowChatParticipants",
    0x2f453e49: "pyrogram.raw.types.InputPrivacyValueAllowCloseFriends",
    0x77cdc9f1: "pyrogram.raw.types.InputPrivacyValueAllowPremium",
    0xfffe1bac: "pyrogram.raw.types.PrivacyValueAllowContacts",
    0x65427b82: "pyrogram.raw.types.PrivacyValueAllowAll",
    0xb8905fb2: "pyrogram.raw.types.PrivacyValueAllowUsers",
    0xf888fa1a: "pyrogram.raw.types.PrivacyValueDisallowContacts",
    0x8b73e763: "pyrogram.raw.types.PrivacyValueDisallowAll",
    0xe4621141: "pyrogram.raw.types.PrivacyValueDisallowUsers",
    0x6b134e8e: "pyrogram.raw.types.PrivacyValueAllowChatParticipants",
    0x41c87565: "pyrogram.raw.types.PrivacyValueDisallowChatParticipants",
    0xf7e8d89b: "pyrogram.raw.types.PrivacyValueAllowCloseFriends",
    0xece9814b: "pyrogram.raw.types.PrivacyValueAllowPremium",
    0x50a04e45: "pyrogram.raw.types.account.PrivacyRules",
    0xb8d0afdf: "pyrogram.raw.types.AccountDaysTTL",
    0x6c37c15c: "pyrogram.raw.types.DocumentAttributeImageSize",
    0x11b58939: "pyrogram.raw.types.DocumentAttributeAnimated",
    0x6319d612: "pyrogram.raw.types.DocumentAttributeSticker",
    0xd38ff1c2: "pyrogram.raw.types.DocumentAttributeVideo",
    0x9852f9c6: "pyrogram.raw.types.DocumentAttributeAudio",
    0x15590068: "pyrogram.raw.types.DocumentAttributeFilename",
    0x9801d2f7: "pyrogram.raw.types.DocumentAttributeHasStickers",
    0xfd149899: "pyrogram.raw.types.DocumentAttributeCustomEmoji",
    0xf1749a22: "pyrogram.raw.types.messages.StickersNotModified",
    0x30a6ec7e: "pyrogram.raw.types.messages.Stickers",
    0x12b299d4: "pyrogram.raw.types.StickerPack",
    0xe86602c3: "pyrogram.raw.types.messages.AllStickersNotModified",
    0xcdbbcebb: "pyrogram.raw.types.messages.AllStickers",
    0x84d19185: "pyrogram.raw.types.messages.AffectedMessages",
    0x211a1788: "pyrogram.raw.types.WebPageEmpty",
    0xb0d13e47: "pyrogram.raw.types.WebPagePending",
    0xe89c45b2: "pyrogram.raw.types.WebPage",
    0x7311ca11: "pyrogram.raw.types.WebPageNotModified",
    0xad01d61d: "pyrogram.raw.types.Authorization",
    0x4bff8ea0: "pyrogram.raw.types.account.Authorizations",
    0x957b50fb: "pyrogram.raw.types.account.Password",
    0x9a5c33e5: "pyrogram.raw.types.account.PasswordSettings",
    0xc23727c9: "pyrogram.raw.types.account.PasswordInputSettings",
    0x137948a5: "pyrogram.raw.types.auth.PasswordRecovery",
    0xa384b779: "pyrogram.raw.types.ReceivedNotifyMessage",
    0xab4a819: "pyrogram.raw.types.ChatInviteExported",
    0xed107ab7: "pyrogram.raw.types.ChatInvitePublicJoinRequests",
    0x5a686d7c: "pyrogram.raw.types.ChatInviteAlready",
    0xcde0ec40: "pyrogram.raw.types.ChatInvite",
    0x61695cb0: "pyrogram.raw.types.ChatInvitePeek",
    0xffb62b95: "pyrogram.raw.types.InputStickerSetEmpty",
    0x9de7a269: "pyrogram.raw.types.InputStickerSetID",
    0x861cc8a0: "pyrogram.raw.types.InputStickerSetShortName",
    0x28703c8: "pyrogram.raw.types.InputStickerSetAnimatedEmoji",
    0xe67f520e: "pyrogram.raw.types.InputStickerSetDice",
    0xcde3739: "pyrogram.raw.types.InputStickerSetAnimatedEmojiAnimations",
    0xc88b3b02: "pyrogram.raw.types.InputStickerSetPremiumGifts",
    0x4c4d4ce: "pyrogram.raw.types.InputStickerSetEmojiGenericAnimations",
    0x29d0f5ee: "pyrogram.raw.types.InputStickerSetEmojiDefaultStatuses",
    0x44c1f8e9: "pyrogram.raw.types.InputStickerSetEmojiDefaultTopicIcons",
    0x49748553: "pyrogram.raw.types.InputStickerSetEmojiChannelDefaultStatuses",
    0x2dd14edc: "pyrogram.raw.types.StickerSet",
    0x6e153f16: "pyrogram.raw.types.messages.StickerSet",
    0xd3f924eb: "pyrogram.raw.types.messages.StickerSetNotModified",
    0xc27ac8c7: "pyrogram.raw.types.BotCommand",
    0x8f300b57: "pyrogram.raw.types.BotInfo",
    0xa2fa4880: "pyrogram.raw.types.KeyboardButton",
    0x258aff05: "pyrogram.raw.types.KeyboardButtonUrl",
    0x35bbdb6b: "pyrogram.raw.types.KeyboardButtonCallback",
    0xb16a6c29: "pyrogram.raw.types.KeyboardButtonRequestPhone",
    0xfc796b3f: "pyrogram.raw.types.KeyboardButtonRequestGeoLocation",
    0x93b9fbb5: "pyrogram.raw.types.KeyboardButtonSwitchInline",
    0x50f41ccf: "pyrogram.raw.types.KeyboardButtonGame",
    0xafd93fbb: "pyrogram.raw.types.KeyboardButtonBuy",
    0x10b78d29: "pyrogram.raw.types.KeyboardButtonUrlAuth",
    0xd02e7fd4: "pyrogram.raw.types.InputKeyboardButtonUrlAuth",
    0xbbc7515d: "pyrogram.raw.types.KeyboardButtonRequestPoll",
    0xe988037b: "pyrogram.raw.types.InputKeyboardButtonUserProfile",
    0x308660c1: "pyrogram.raw.types.KeyboardButtonUserProfile",
    0x13767230: "pyrogram.raw.types.KeyboardButtonWebView",
    0xa0c0505c: "pyrogram.raw.types.KeyboardButtonSimpleWebView",
    0x53d7bfd8: "pyrogram.raw.types.KeyboardButtonRequestPeer",
    0xc9662d05: "pyrogram.raw.types.InputKeyboardButtonRequestPeer",
    0x77608b83: "pyrogram.raw.types.KeyboardButtonRow",
    0xa03e5b85: "pyrogram.raw.types.ReplyKeyboardHide",
    0x86b40b08: "pyrogram.raw.types.ReplyKeyboardForceReply",
    0x85dd99d1: "pyrogram.raw.types.ReplyKeyboardMarkup",
    0x48a30254: "pyrogram.raw.types.ReplyInlineMarkup",
    0xbb92ba95: "pyrogram.raw.types.MessageEntityUnknown",
    0xfa04579d: "pyrogram.raw.types.MessageEntityMention",
    0x6f635b0d: "pyrogram.raw.types.MessageEntityHashtag",
    0x6cef8ac7: "pyrogram.raw.types.MessageEntityBotCommand",
    0x6ed02538: "pyrogram.raw.types.MessageEntityUrl",
    0x64e475c2: "pyrogram.raw.types.MessageEntityEmail",
    0xbd610bc9: "pyrogram.raw.types.MessageEntityBold",
    0x826f8b60: "pyrogram.raw.types.MessageEntityItalic",
    0x28a20571: "pyrogram.raw.types.MessageEntityCode",
    0x73924be0: "pyrogram.raw.types.MessageEntityPre",
    0x76a6d327: "pyrogram.raw.types.MessageEntityTextUrl",
    0xdc7b1140: "pyrogram.raw.types.MessageEntityMentionName",
    0x208e68c9: "pyrogram.raw.types.InputMessageEntityMentionName",
    0x9b69e34b: "pyrogram.raw.types.MessageEntityPhone",
    0x4c4e743f: "pyrogram.raw.types.MessageEntityCashtag",
    0x9c4e7e8b: "pyrogram.raw.types.MessageEntityUnderline",
    0xbf0693d4: "pyrogram.raw.types.MessageEntityStrike",
    0x761e6af4: "pyrogram.raw.types.MessageEntityBankCard",
    0x32ca960f: "pyrogram.raw.types.MessageEntitySpoiler",
    0xc8cf05f8: "pyrogram.raw.types.MessageEntityCustomEmoji",
    0x20df5d0: "pyrogram.raw.types.MessageEntityBlockquote",
    0xee8c1e86: "pyrogram.raw.types.InputChannelEmpty",
    0xf35aec28: "pyrogram.raw.types.InputChannel",
    0x5b934f9d: "pyrogram.raw.types.InputChannelFromMessage",
    0x7f077ad9: "pyrogram.raw.types.contacts.ResolvedPeer",
    0xae30253: "pyrogram.raw.types.MessageRange",
    0x3e11affb: "pyrogram.raw.types.updates.ChannelDifferenceEmpty",
    0xa4bcc6fe: "pyrogram.raw.types.updates.ChannelDifferenceTooLong",
    0x2064674e: "pyrogram.raw.types.updates.ChannelDifference",
    0x94d42ee7: "pyrogram.raw.types.ChannelMessagesFilterEmpty",
    0xcd77d957: "pyrogram.raw.types.ChannelMessagesFilter",
    0xc00c07c0: "pyrogram.raw.types.ChannelParticipant",
    0x35a8bfa7: "pyrogram.raw.types.ChannelParticipantSelf",
    0x2fe601d3: "pyrogram.raw.types.ChannelParticipantCreator",
    0x34c3bb53: "pyrogram.raw.types.ChannelParticipantAdmin",
    0x6df8014e: "pyrogram.raw.types.ChannelParticipantBanned",
    0x1b03f006: "pyrogram.raw.types.ChannelParticipantLeft",
    0xde3f3c79: "pyrogram.raw.types.ChannelParticipantsRecent",
    0xb4608969: "pyrogram.raw.types.ChannelParticipantsAdmins",
    0xa3b54985: "pyrogram.raw.types.ChannelParticipantsKicked",
    0xb0d1865b: "pyrogram.raw.types.ChannelParticipantsBots",
    0x1427a5e1: "pyrogram.raw.types.ChannelParticipantsBanned",
    0x656ac4b: "pyrogram.raw.types.ChannelParticipantsSearch",
    0xbb6ae88d: "pyrogram.raw.types.ChannelParticipantsContacts",
    0xe04b5ceb: "pyrogram.raw.types.ChannelParticipantsMentions",
    0x9ab0feaf: "pyrogram.raw.types.channels.ChannelParticipants",
    0xf0173fe9: "pyrogram.raw.types.channels.ChannelParticipantsNotModified",
    0xdfb80317: "pyrogram.raw.types.channels.ChannelParticipant",
    0x780a0310: "pyrogram.raw.types.help.TermsOfService",
    0xe8025ca2: "pyrogram.raw.types.messages.SavedGifsNotModified",
    0x84a02a0d: "pyrogram.raw.types.messages.SavedGifs",
    0x3380c786: "pyrogram.raw.types.InputBotInlineMessageMediaAuto",
    0x3dcd7a87: "pyrogram.raw.types.InputBotInlineMessageText",
    0x96929a85: "pyrogram.raw.types.InputBotInlineMessageMediaGeo",
    0x417bbf11: "pyrogram.raw.types.InputBotInlineMessageMediaVenue",
    0xa6edbffd: "pyrogram.raw.types.InputBotInlineMessageMediaContact",
    0x4b425864: "pyrogram.raw.types.InputBotInlineMessageGame",
    0xd7e78225: "pyrogram.raw.types.InputBotInlineMessageMediaInvoice",
    0xbddcc510: "pyrogram.raw.types.InputBotInlineMessageMediaWebPage",
    0x88bf9319: "pyrogram.raw.types.InputBotInlineResult",
    0xa8d864a7: "pyrogram.raw.types.InputBotInlineResultPhoto",
    0xfff8fdc4: "pyrogram.raw.types.InputBotInlineResultDocument",
    0x4fa417f2: "pyrogram.raw.types.InputBotInlineResultGame",
    0x764cf810: "pyrogram.raw.types.BotInlineMessageMediaAuto",
    0x8c7f65e2: "pyrogram.raw.types.BotInlineMessageText",
    0x51846fd: "pyrogram.raw.types.BotInlineMessageMediaGeo",
    0x8a86659c: "pyrogram.raw.types.BotInlineMessageMediaVenue",
    0x18d1cdc2: "pyrogram.raw.types.BotInlineMessageMediaContact",
    0x354a9b09: "pyrogram.raw.types.BotInlineMessageMediaInvoice",
    0x809ad9a6: "pyrogram.raw.types.BotInlineMessageMediaWebPage",
    0x11965f3a: "pyrogram.raw.types.BotInlineResult",
    0x17db940b: "pyrogram.raw.types.BotInlineMediaResult",
    0xe021f2f6: "pyrogram.raw.types.messages.BotResults",
    0x5dab1af4: "pyrogram.raw.types.ExportedMessageLink",
    0x4e4df4bb: "pyrogram.raw.types.MessageFwdHeader",
    0x72a3158c: "pyrogram.raw.types.auth.CodeTypeSms",
    0x741cd3e3: "pyrogram.raw.types.auth.CodeTypeCall",
    0x226ccefb: "pyrogram.raw.types.auth.CodeTypeFlashCall",
    0xd61ad6ee: "pyrogram.raw.types.auth.CodeTypeMissedCall",
    0x6ed998c: "pyrogram.raw.types.auth.CodeTypeFragmentSms",
    0x3dbb5986: "pyrogram.raw.types.auth.SentCodeTypeApp",
    0xc000bba2: "pyrogram.raw.types.auth.SentCodeTypeSms",
    0x5353e5a7: "pyrogram.raw.types.auth.SentCodeTypeCall",
    0xab03c6d9: "pyrogram.raw.types.auth.SentCodeTypeFlashCall",
    0x82006484: "pyrogram.raw.types.auth.SentCodeTypeMissedCall",
    0xf450f59b: "pyrogram.raw.types.auth.SentCodeTypeEmailCode",
    0xa5491dea: "pyrogram.raw.types.auth.SentCodeTypeSetUpEmailRequired",
    0xd9565c39: "pyrogram.raw.types.auth.SentCodeTypeFragmentSms",
    0xe57b1432: "pyrogram.raw.types.auth.SentCodeTypeFirebaseSms",
    0x36585ea4: "pyrogram.raw.types.messages.BotCallbackAnswer",
    0x26b5dde6: "pyrogram.raw.types.messages.MessageEditData",
    0x890c3d89: "pyrogram.raw.types.InputBotInlineMessageID",
    0xb6d915d7: "pyrogram.raw.types.InputBotInlineMessageID64",
    0x3c20629f: "pyrogram.raw.types.InlineBotSwitchPM",
    0x3371c354: "pyrogram.raw.types.messages.PeerDialogs",
    0xedcdc05b: "pyrogram.raw.types.TopPeer",
    0xab661b5b: "pyrogram.raw.types.TopPeerCategoryBotsPM",
    0x148677e2: "pyrogram.raw.types.TopPeerCategoryBotsInline",
    0x637b7ed: "pyrogram.raw.types.TopPeerCategoryCorrespondents",
    0xbd17a14a: "pyrogram.raw.types.TopPeerCategoryGroups",
    0x161d9628: "pyrogram.raw.types.TopPeerCategoryChannels",
    0x1e76a78c: "pyrogram.raw.types.TopPeerCategoryPhoneCalls",
    0xa8406ca9: "pyrogram.raw.types.TopPeerCategoryForwardUsers",
    0xfbeec0f0: "pyrogram.raw.types.TopPeerCategoryForwardChats",
    0xfb834291: "pyrogram.raw.types.TopPeerCategoryPeers",
    0xde266ef5: "pyrogram.raw.types.contacts.TopPeersNotModified",
    0x70b772a8: "pyrogram.raw.types.contacts.TopPeers",
    0xb52c939d: "pyrogram.raw.types.contacts.TopPeersDisabled",
    0x1b0c841a: "pyrogram.raw.types.DraftMessageEmpty",
    0x3fccf7ef: "pyrogram.raw.types.DraftMessage",
    0xc6dc0c66: "pyrogram.raw.types.messages.FeaturedStickersNotModified",
    0xbe382906: "pyrogram.raw.types.messages.FeaturedStickers",
    0xb17f890: "pyrogram.raw.types.messages.RecentStickersNotModified",
    0x88d37c56: "pyrogram.raw.types.messages.RecentStickers",
    0x4fcba9c8: "pyrogram.raw.types.messages.ArchivedStickers",
    0x38641628: "pyrogram.raw.types.messages.StickerSetInstallResultSuccess",
    0x35e410a8: "pyrogram.raw.types.messages.StickerSetInstallResultArchive",
    0x6410a5d2: "pyrogram.raw.types.StickerSetCovered",
    0x3407e51b: "pyrogram.raw.types.StickerSetMultiCovered",
    0x40d13c0e: "pyrogram.raw.types.StickerSetFullCovered",
    0x77b15d1c: "pyrogram.raw.types.StickerSetNoCovered",
    0xaed6dbb2: "pyrogram.raw.types.MaskCoords",
    0x4a992157: "pyrogram.raw.types.InputStickeredMediaPhoto",
    0x438865b: "pyrogram.raw.types.InputStickeredMediaDocument",
    0xbdf9653b: "pyrogram.raw.types.Game",
    0x32c3e77: "pyrogram.raw.types.InputGameID",
    0xc331e80a: "pyrogram.raw.types.InputGameShortName",
    0x73a379eb: "pyrogram.raw.types.HighScore",
    0x9a3bfd99: "pyrogram.raw.types.messages.HighScores",
    0xdc3d824f: "pyrogram.raw.types.TextEmpty",
    0x744694e0: "pyrogram.raw.types.TextPlain",
    0x6724abc4: "pyrogram.raw.types.TextBold",
    0xd912a59c: "pyrogram.raw.types.TextItalic",
    0xc12622c4: "pyrogram.raw.types.TextUnderline",
    0x9bf8bb95: "pyrogram.raw.types.TextStrike",
    0x6c3f19b9: "pyrogram.raw.types.TextFixed",
    0x3c2884c1: "pyrogram.raw.types.TextUrl",
    0xde5a0dd6: "pyrogram.raw.types.TextEmail",
    0x7e6260d7: "pyrogram.raw.types.TextConcat",
    0xed6a8504: "pyrogram.raw.types.TextSubscript",
    0xc7fb5e01: "pyrogram.raw.types.TextSuperscript",
    0x34b8621: "pyrogram.raw.types.TextMarked",
    0x1ccb966a: "pyrogram.raw.types.TextPhone",
    0x81ccf4f: "pyrogram.raw.types.TextImage",
    0x35553762: "pyrogram.raw.types.TextAnchor",
    0x13567e8a: "pyrogram.raw.types.PageBlockUnsupported",
    0x70abc3fd: "pyrogram.raw.types.PageBlockTitle",
    0x8ffa9a1f: "pyrogram.raw.types.PageBlockSubtitle",
    0xbaafe5e0: "pyrogram.raw.types.PageBlockAuthorDate",
    0xbfd064ec: "pyrogram.raw.types.PageBlockHeader",
    0xf12bb6e1: "pyrogram.raw.types.PageBlockSubheader",
    0x467a0766: "pyrogram.raw.types.PageBlockParagraph",
    0xc070d93e: "pyrogram.raw.types.PageBlockPreformatted",
    0x48870999: "pyrogram.raw.types.PageBlockFooter",
    0xdb20b188: "pyrogram.raw.types.PageBlockDivider",
    0xce0d37b0: "pyrogram.raw.types.PageBlockAnchor",
    0xe4e88011: "pyrogram.raw.types.PageBlockList",
    0x263d7c26: "pyrogram.raw.types.PageBlockBlockquote",
    0x4f4456d3: "pyrogram.raw.types.PageBlockPullquote",
    0x1759c560: "pyrogram.raw.types.PageBlockPhoto",
    0x7c8fe7b6: "pyrogram.raw.types.PageBlockVideo",
    0x39f23300: "pyrogram.raw.types.PageBlockCover",
    0xa8718dc5: "pyrogram.raw.types.PageBlockEmbed",
    0xf259a80b: "pyrogram.raw.types.PageBlockEmbedPost",
    0x65a0fa4d: "pyrogram.raw.types.PageBlockCollage",
    0x31f9590: "pyrogram.raw.types.PageBlockSlideshow",
    0xef1751b5: "pyrogram.raw.types.PageBlockChannel",
    0x804361ea: "pyrogram.raw.types.PageBlockAudio",
    0x1e148390: "pyrogram.raw.types.PageBlockKicker",
    0xbf4dea82: "pyrogram.raw.types.PageBlockTable",
    0x9a8ae1e1: "pyrogram.raw.types.PageBlockOrderedList",
    0x76768bed: "pyrogram.raw.types.PageBlockDetails",
    0x16115a96: "pyrogram.raw.types.PageBlockRelatedArticles",
    0xa44f3ef6: "pyrogram.raw.types.PageBlockMap",
    0x85e42301: "pyrogram.raw.types.PhoneCallDiscardReasonMissed",
    0xe095c1a0: "pyrogram.raw.types.PhoneCallDiscardReasonDisconnect",
    0x57adc690: "pyrogram.raw.types.PhoneCallDiscardReasonHangup",
    0xfaf7e8c9: "pyrogram.raw.types.PhoneCallDiscardReasonBusy",
    0x7d748d04: "pyrogram.raw.types.DataJSON",
    0xcb296bf8: "pyrogram.raw.types.LabeledPrice",
    0x5db95a15: "pyrogram.raw.types.Invoice",
    0xea02c27e: "pyrogram.raw.types.PaymentCharge",
    0x1e8caaeb: "pyrogram.raw.types.PostAddress",
    0x909c3f94: "pyrogram.raw.types.PaymentRequestedInfo",
    0xcdc27a1f: "pyrogram.raw.types.PaymentSavedCredentialsCard",
    0x1c570ed1: "pyrogram.raw.types.WebDocument",
    0xf9c8bcc6: "pyrogram.raw.types.WebDocumentNoProxy",
    0x9bed434d: "pyrogram.raw.types.InputWebDocument",
    0xc239d686: "pyrogram.raw.types.InputWebFileLocation",
    0x9f2221c9: "pyrogram.raw.types.InputWebFileGeoPointLocation",
    0xf46fe924: "pyrogram.raw.types.InputWebFileAudioAlbumThumbLocation",
    0x21e753bc: "pyrogram.raw.types.upload.WebFile",
    0xa0058751: "pyrogram.raw.types.payments.PaymentForm",
    0xd1451883: "pyrogram.raw.types.payments.ValidatedRequestedInfo",
    0x4e5f810d: "pyrogram.raw.types.payments.PaymentResult",
    0xd8411139: "pyrogram.raw.types.payments.PaymentVerificationNeeded",
    0x70c4fe03: "pyrogram.raw.types.payments.PaymentReceipt",
    0xfb8fe43c: "pyrogram.raw.types.payments.SavedInfo",
    0xc10eb2cf: "pyrogram.raw.types.InputPaymentCredentialsSaved",
    0x3417d728: "pyrogram.raw.types.InputPaymentCredentials",
    0xaa1c39f: "pyrogram.raw.types.InputPaymentCredentialsApplePay",
    0x8ac32801: "pyrogram.raw.types.InputPaymentCredentialsGooglePay",
    0xdb64fd34: "pyrogram.raw.types.account.TmpPassword",
    0xb6213cdf: "pyrogram.raw.types.ShippingOption",
    0x32da9e9c: "pyrogram.raw.types.InputStickerSetItem",
    0x1e36fded: "pyrogram.raw.types.InputPhoneCall",
    0x5366c915: "pyrogram.raw.types.PhoneCallEmpty",
    0xc5226f17: "pyrogram.raw.types.PhoneCallWaiting",
    0x14b0ed0c: "pyrogram.raw.types.PhoneCallRequested",
    0x3660c311: "pyrogram.raw.types.PhoneCallAccepted",
    0x30535af5: "pyrogram.raw.types.PhoneCall",
    0x50ca4de1: "pyrogram.raw.types.PhoneCallDiscarded",
    0x9cc123c7: "pyrogram.raw.types.PhoneConnection",
    0x635fe375: "pyrogram.raw.types.PhoneConnectionWebrtc",
    0xfc878fc8: "pyrogram.raw.types.PhoneCallProtocol",
    0xec82e140: "pyrogram.raw.types.phone.PhoneCall",
    0xeea8e46e: "pyrogram.raw.types.upload.CdnFileReuploadNeeded",
    0xa99fca4f: "pyrogram.raw.types.upload.CdnFile",
    0xc982eaba: "pyrogram.raw.types.CdnPublicKey",
    0x5725e40a: "pyrogram.raw.types.CdnConfig",
    0xcad181f6: "pyrogram.raw.types.LangPackString",
    0x6c47ac9f: "pyrogram.raw.types.LangPackStringPluralized",
    0x2979eeb2: "pyrogram.raw.types.LangPackStringDeleted",
    0xf385c1f6: "pyrogram.raw.types.LangPackDifference",
    0xeeca5ce3: "pyrogram.raw.types.LangPackLanguage",
    0xe6dfb825: "pyrogram.raw.types.ChannelAdminLogEventActionChangeTitle",
    0x55188a2e: "pyrogram.raw.types.ChannelAdminLogEventActionChangeAbout",
    0x6a4afc38: "pyrogram.raw.types.ChannelAdminLogEventActionChangeUsername",
    0x434bd2af: "pyrogram.raw.types.ChannelAdminLogEventActionChangePhoto",
    0x1b7907ae: "pyrogram.raw.types.ChannelAdminLogEventActionToggleInvites",
    0x26ae0971: "pyrogram.raw.types.ChannelAdminLogEventActionToggleSignatures",
    0xe9e82c18: "pyrogram.raw.types.ChannelAdminLogEventActionUpdatePinned",
    0x709b2405: "pyrogram.raw.types.ChannelAdminLogEventActionEditMessage",
    0x42e047bb: "pyrogram.raw.types.ChannelAdminLogEventActionDeleteMessage",
    0x183040d3: "pyrogram.raw.types.ChannelAdminLogEventActionParticipantJoin",
    0xf89777f2: "pyrogram.raw.types.ChannelAdminLogEventActionParticipantLeave",
    0xe31c34d8: "pyrogram.raw.types.ChannelAdminLogEventActionParticipantInvite",
    0xe6d83d7e: "pyrogram.raw.types.ChannelAdminLogEventActionParticipantToggleBan",
    0xd5676710: "pyrogram.raw.types.ChannelAdminLogEventActionParticipantToggleAdmin",
    0xb1c3caa7: "pyrogram.raw.types.ChannelAdminLogEventActionChangeStickerSet",
    0x5f5c95f1: "pyrogram.raw.types.ChannelAdminLogEventActionTogglePreHistoryHidden",
    0x2df5fc0a: "pyrogram.raw.types.ChannelAdminLogEventActionDefaultBannedRights",
    0x8f079643: "pyrogram.raw.types.ChannelAdminLogEventActionStopPoll",
    0x50c7ac8: "pyrogram.raw.types.ChannelAdminLogEventActionChangeLinkedChat",
    0xe6b76ae: "pyrogram.raw.types.ChannelAdminLogEventActionChangeLocation",
    0x53909779: "pyrogram.raw.types.ChannelAdminLogEventActionToggleSlowMode",
    0x23209745: "pyrogram.raw.types.ChannelAdminLogEventActionStartGroupCall",
    0xdb9f9140: "pyrogram.raw.types.ChannelAdminLogEventActionDiscardGroupCall",
    0xf92424d2: "pyrogram.raw.types.ChannelAdminLogEventActionParticipantMute",
    0xe64429c0: "pyrogram.raw.types.ChannelAdminLogEventActionParticipantUnmute",
    0x56d6a247: "pyrogram.raw.types.ChannelAdminLogEventActionToggleGroupCallSetting",
    0xfe9fc158: "pyrogram.raw.types.ChannelAdminLogEventActionParticipantJoinByInvite",
    0x5a50fca4: "pyrogram.raw.types.ChannelAdminLogEventActionExportedInviteDelete",
    0x410a134e: "pyrogram.raw.types.ChannelAdminLogEventActionExportedInviteRevoke",
    0xe90ebb59: "pyrogram.raw.types.ChannelAdminLogEventActionExportedInviteEdit",
    0x3e7f6847: "pyrogram.raw.types.ChannelAdminLogEventActionParticipantVolume",
    0x6e941a38: "pyrogram.raw.types.ChannelAdminLogEventActionChangeHistoryTTL",
    0xafb6144a: "pyrogram.raw.types.ChannelAdminLogEventActionParticipantJoinByRequest",
    0xcb2ac766: "pyrogram.raw.types.ChannelAdminLogEventActionToggleNoForwards",
    0x278f2868: "pyrogram.raw.types.ChannelAdminLogEventActionSendMessage",
    0xbe4e0ef8: "pyrogram.raw.types.ChannelAdminLogEventActionChangeAvailableReactions",
    0xf04fb3a9: "pyrogram.raw.types.ChannelAdminLogEventActionChangeUsernames",
    0x2cc6383: "pyrogram.raw.types.ChannelAdminLogEventActionToggleForum",
    0x58707d28: "pyrogram.raw.types.ChannelAdminLogEventActionCreateTopic",
    0xf06fe208: "pyrogram.raw.types.ChannelAdminLogEventActionEditTopic",
    0xae168909: "pyrogram.raw.types.ChannelAdminLogEventActionDeleteTopic",
    0x5d8d353b: "pyrogram.raw.types.ChannelAdminLogEventActionPinTopic",
    0x64f36dfc: "pyrogram.raw.types.ChannelAdminLogEventActionToggleAntiSpam",
    0x5796e780: "pyrogram.raw.types.ChannelAdminLogEventActionChangePeerColor",
    0x5e477b25: "pyrogram.raw.types.ChannelAdminLogEventActionChangeProfilePeerColor",
    0x31bb5d52: "pyrogram.raw.types.ChannelAdminLogEventActionChangeWallpaper",
    0x3ea9feb1: "pyrogram.raw.types.ChannelAdminLogEventActionChangeEmojiStatus",
    0x46d840ab: "pyrogram.raw.types.ChannelAdminLogEventActionChangeEmojiStickerSet",
    0x1fad68cd: "pyrogram.raw.types.ChannelAdminLogEvent",
    0xed8af74d: "pyrogram.raw.types.channels.AdminLogResults",
    0xea107ae4: "pyrogram.raw.types.ChannelAdminLogEventsFilter",
    0x5ce14175: "pyrogram.raw.types.PopularContact",
    0x9e8fa6d3: "pyrogram.raw.types.messages.FavedStickersNotModified",
    0x2cb51097: "pyrogram.raw.types.messages.FavedStickers",
    0x46e1d13d: "pyrogram.raw.types.RecentMeUrlUnknown",
    0xb92c09e2: "pyrogram.raw.types.RecentMeUrlUser",
    0xb2da71d2: "pyrogram.raw.types.RecentMeUrlChat",
    0xeb49081d: "pyrogram.raw.types.RecentMeUrlChatInvite",
    0xbc0a57dc: "pyrogram.raw.types.RecentMeUrlStickerSet",
    0xe0310d7: "pyrogram.raw.types.help.RecentMeUrls",
    0x1cc6e91f: "pyrogram.raw.types.InputSingleMedia",
    0xa6f8f452: "pyrogram.raw.types.WebAuthorization",
    0xed56c9fc: "pyrogram.raw.types.account.WebAuthorizations",
    0xa676a322: "pyrogram.raw.types.InputMessageID",
    0xbad88395: "pyrogram.raw.types.InputMessageReplyTo",
    0x86872538: "pyrogram.raw.types.InputMessagePinned",
    0xacfa1a7e: "pyrogram.raw.types.InputMessageCallbackQuery",
    0xfcaafeb7: "pyrogram.raw.types.InputDialogPeer",
    0x64600527: "pyrogram.raw.types.InputDialogPeerFolder",
    0xe56dbf05: "pyrogram.raw.types.DialogPeer",
    0x514519e2: "pyrogram.raw.types.DialogPeerFolder",
    0xd54b65d: "pyrogram.raw.types.messages.FoundStickerSetsNotModified",
    0x8af09dd2: "pyrogram.raw.types.messages.FoundStickerSets",
    0xf39b035c: "pyrogram.raw.types.FileHash",
    0x75588b3f: "pyrogram.raw.types.InputClientProxy",
    0xe3309f7f: "pyrogram.raw.types.help.TermsOfServiceUpdateEmpty",
    0x28ecf961: "pyrogram.raw.types.help.TermsOfServiceUpdate",
    0x3334b0f0: "pyrogram.raw.types.InputSecureFileUploaded",
    0x5367e5be: "pyrogram.raw.types.InputSecureFile",
    0x64199744: "pyrogram.raw.types.SecureFileEmpty",
    0x7d09c27e: "pyrogram.raw.types.SecureFile",
    0x8aeabec3: "pyrogram.raw.types.SecureData",
    0x7d6099dd: "pyrogram.raw.types.SecurePlainPhone",
    0x21ec5a5f: "pyrogram.raw.types.SecurePlainEmail",
    0x9d2a81e3: "pyrogram.raw.types.SecureValueTypePersonalDetails",
    0x3dac6a00: "pyrogram.raw.types.SecureValueTypePassport",
    0x6e425c4: "pyrogram.raw.types.SecureValueTypeDriverLicense",
    0xa0d0744b: "pyrogram.raw.types.SecureValueTypeIdentityCard",
    0x99a48f23: "pyrogram.raw.types.SecureValueTypeInternalPassport",
    0xcbe31e26: "pyrogram.raw.types.SecureValueTypeAddress",
    0xfc36954e: "pyrogram.raw.types.SecureValueTypeUtilityBill",
    0x89137c0d: "pyrogram.raw.types.SecureValueTypeBankStatement",
    0x8b883488: "pyrogram.raw.types.SecureValueTypeRentalAgreement",
    0x99e3806a: "pyrogram.raw.types.SecureValueTypePassportRegistration",
    0xea02ec33: "pyrogram.raw.types.SecureValueTypeTemporaryRegistration",
    0xb320aadb: "pyrogram.raw.types.SecureValueTypePhone",
    0x8e3ca7ee: "pyrogram.raw.types.SecureValueTypeEmail",
    0x187fa0ca: "pyrogram.raw.types.SecureValue",
    0xdb21d0a7: "pyrogram.raw.types.InputSecureValue",
    0xed1ecdb0: "pyrogram.raw.types.SecureValueHash",
    0xe8a40bd9: "pyrogram.raw.types.SecureValueErrorData",
    0xbe3dfa: "pyrogram.raw.types.SecureValueErrorFrontSide",
    0x868a2aa5: "pyrogram.raw.types.SecureValueErrorReverseSide",
    0xe537ced6: "pyrogram.raw.types.SecureValueErrorSelfie",
    0x7a700873: "pyrogram.raw.types.SecureValueErrorFile",
    0x666220e9: "pyrogram.raw.types.SecureValueErrorFiles",
    0x869d758f: "pyrogram.raw.types.SecureValueError",
    0xa1144770: "pyrogram.raw.types.SecureValueErrorTranslationFile",
    0x34636dd8: "pyrogram.raw.types.SecureValueErrorTranslationFiles",
    0x33f0ea47: "pyrogram.raw.types.SecureCredentialsEncrypted",
    0xad2e1cd8: "pyrogram.raw.types.account.AuthorizationForm",
    0x811f854f: "pyrogram.raw.types.account.SentEmailCode",
    0x66afa166: "pyrogram.raw.types.help.DeepLinkInfoEmpty",
    0x6a4ee832: "pyrogram.raw.types.help.DeepLinkInfo",
    0x1142bd56: "pyrogram.raw.types.SavedPhoneContact",
    0x4dba4501: "pyrogram.raw.types.account.Takeout",
    0xd45ab096: "pyrogram.raw.types.PasswordKdfAlgoUnknown",
    0x3a912d4a: "pyrogram.raw.types.PasswordKdfAlgoSHA256SHA256PBKDF2HMACSHA512iter100000SHA256ModPow",
    0x4a8537: "pyrogram.raw.types.SecurePasswordKdfAlgoUnknown",
    0xbbf2dda0: "pyrogram.raw.types.SecurePasswordKdfAlgoPBKDF2HMACSHA512iter100000",
    0x86471d92: "pyrogram.raw.types.SecurePasswordKdfAlgoSHA512",
    0x1527bcac: "pyrogram.raw.types.SecureSecretSettings",
    0x9880f658: "pyrogram.raw.types.InputCheckPasswordEmpty",
    0xd27ff082: "pyrogram.raw.types.InputCheckPasswordSRP",
    0x829d99da: "pyrogram.raw.types.SecureRequiredType",
    0x27477b4: "pyrogram.raw.types.SecureRequiredTypeOneOf",
    0xbfb9f457: "pyrogram.raw.types.help.PassportConfigNotModified",
    0xa098d6af: "pyrogram.raw.types.help.PassportConfig",
    0x1d1b1245: "pyrogram.raw.types.InputAppEvent",
    0xc0de1bd9: "pyrogram.raw.types.JsonObjectValue",
    0x3f6d7b68: "pyrogram.raw.types.JsonNull",
    0xc7345e6a: "pyrogram.raw.types.JsonBool",
    0x2be0dfa4: "pyrogram.raw.types.JsonNumber",
    0xb71e767a: "pyrogram.raw.types.JsonString",
    0xf7444763: "pyrogram.raw.types.JsonArray",
    0x99c1d49d: "pyrogram.raw.types.JsonObject",
    0x34566b6a: "pyrogram.raw.types.PageTableCell",
    0xe0c0c5e5: "pyrogram.raw.types.PageTableRow",
    0x6f747657: "pyrogram.raw.types.PageCaption",
    0xb92fb6cd: "pyrogram.raw.types.PageListItemText",
    0x25e073fc: "pyrogram.raw.types.PageListItemBlocks",
    0x5e068047: "pyrogram.raw.types.PageListOrderedItemText",
    0x98dd8936: "pyrogram.raw.types.PageListOrderedItemBlocks",
    0xb390dc08: "pyrogram.raw.types.PageRelatedArticle",
    0x98657f0d: "pyrogram.raw.types.Page",
    0x8c05f1c9: "pyrogram.raw.types.help.SupportName",
    0xf3ae2eed: "pyrogram.raw.types.help.UserInfoEmpty",
    0x1eb3758: "pyrogram.raw.types.help.UserInfo",
    0x6ca9c2e9: "pyrogram.raw.types.PollAnswer",
    0x86e18161: "pyrogram.raw.types.Poll",
    0x3b6ddad2: "pyrogram.raw.types.PollAnswerVoters",
    0x7adf2420: "pyrogram.raw.types.PollResults",
    0xf041e250: "pyrogram.raw.types.ChatOnlines",
    0x47a971e0: "pyrogram.raw.types.StatsURL",
    0x5fb224d5: "pyrogram.raw.types.ChatAdminRights",
    0x9f120418: "pyrogram.raw.types.ChatBannedRights",
    0xe630b979: "pyrogram.raw.types.InputWallPaper",
    0x72091c80: "pyrogram.raw.types.InputWallPaperSlug",
    0x967a462e: "pyrogram.raw.types.InputWallPaperNoFile",
    0x1c199183: "pyrogram.raw.types.account.WallPapersNotModified",
    0xcdc3858c: "pyrogram.raw.types.account.WallPapers",
    0xad253d78: "pyrogram.raw.types.CodeSettings",
    0x372efcd0: "pyrogram.raw.types.WallPaperSettings",
    0xbaa57628: "pyrogram.raw.types.AutoDownloadSettings",
    0x63cacf26: "pyrogram.raw.types.account.AutoDownloadSettings",
    0xd5b3b9f9: "pyrogram.raw.types.EmojiKeyword",
    0x236df622: "pyrogram.raw.types.EmojiKeywordDeleted",
    0x5cc761bd: "pyrogram.raw.types.EmojiKeywordsDifference",
    0xa575739d: "pyrogram.raw.types.EmojiURL",
    0xb3fb5361: "pyrogram.raw.types.EmojiLanguage",
    0xff544e65: "pyrogram.raw.types.Folder",
    0xfbd2c296: "pyrogram.raw.types.InputFolderPeer",
    0xe9baa668: "pyrogram.raw.types.FolderPeer",
    0xe844ebff: "pyrogram.raw.types.messages.SearchCounter",
    0x92d33a0e: "pyrogram.raw.types.UrlAuthResultRequest",
    0x8f8c0e4e: "pyrogram.raw.types.UrlAuthResultAccepted",
    0xa9d6db1f: "pyrogram.raw.types.UrlAuthResultDefault",
    0xbfb5ad8b: "pyrogram.raw.types.ChannelLocationEmpty",
    0x209b82db: "pyrogram.raw.types.ChannelLocation",
    0xca461b5d: "pyrogram.raw.types.PeerLocated",
    0xf8ec284b: "pyrogram.raw.types.PeerSelfLocated",
    0xd072acb4: "pyrogram.raw.types.RestrictionReason",
    0x3c5693e9: "pyrogram.raw.types.InputTheme",
    0xf5890df1: "pyrogram.raw.types.InputThemeSlug",
    0xa00e67d6: "pyrogram.raw.types.Theme",
    0xf41eb622: "pyrogram.raw.types.account.ThemesNotModified",
    0x9a3d8c6d: "pyrogram.raw.types.account.Themes",
    0x629f1980: "pyrogram.raw.types.auth.LoginToken",
    0x68e9916: "pyrogram.raw.types.auth.LoginTokenMigrateTo",
    0x390d5c5e: "pyrogram.raw.types.auth.LoginTokenSuccess",
    0x57e28221: "pyrogram.raw.types.account.ContentSettings",
    0xa927fec5: "pyrogram.raw.types.messages.InactiveChats",
    0xc3a12462: "pyrogram.raw.types.BaseThemeClassic",
    0xfbd81688: "pyrogram.raw.types.BaseThemeDay",
    0xb7b31ea8: "pyrogram.raw.types.BaseThemeNight",
    0x6d5f77ee: "pyrogram.raw.types.BaseThemeTinted",
    0x5b11125a: "pyrogram.raw.types.BaseThemeArctic",
    0x8fde504f: "pyrogram.raw.types.InputThemeSettings",
    0xfa58b6d4: "pyrogram.raw.types.ThemeSettings",
    0x54b56617: "pyrogram.raw.types.WebPageAttributeTheme",
    0x2e94c3e7: "pyrogram.raw.types.WebPageAttributeStory",
    0x4899484e: "pyrogram.raw.types.messages.VotesList",
    0xf568028a: "pyrogram.raw.types.BankCardOpenUrl",
    0x3e24e573: "pyrogram.raw.types.payments.BankCardData",
    0x5fb5523b: "pyrogram.raw.types.DialogFilter",
    0x363293ae: "pyrogram.raw.types.DialogFilterDefault",
    0x9fe28ea4: "pyrogram.raw.types.DialogFilterChatlist",
    0x77744d4a: "pyrogram.raw.types.DialogFilterSuggested",
    0xb637edaf: "pyrogram.raw.types.StatsDateRangeDays",
    0xcb43acde: "pyrogram.raw.types.StatsAbsValueAndPrev",
    0xcbce2fe0: "pyrogram.raw.types.StatsPercentValue",
    0x4a27eb2d: "pyrogram.raw.types.StatsGraphAsync",
    0xbedc9822: "pyrogram.raw.types.StatsGraphError",
    0x8ea464b6: "pyrogram.raw.types.StatsGraph",
    0x396ca5fc: "pyrogram.raw.types.stats.BroadcastStats",
    0x98f6ac75: "pyrogram.raw.types.help.PromoDataEmpty",
    0x8c39793f: "pyrogram.raw.types.help.PromoData",
    0xde33b094: "pyrogram.raw.types.VideoSize",
    0xf85c413c: "pyrogram.raw.types.VideoSizeEmojiMarkup",
    0xda082fe: "pyrogram.raw.types.VideoSizeStickerMarkup",
    0x9d04af9b: "pyrogram.raw.types.StatsGroupTopPoster",
    0xd7584c87: "pyrogram.raw.types.StatsGroupTopAdmin",
    0x535f779d: "pyrogram.raw.types.StatsGroupTopInviter",
    0xef7ff916: "pyrogram.raw.types.stats.MegagroupStats",
    0x734c4ccb: "pyrogram.raw.types.GlobalPrivacySettings",
    0x4203c5ef: "pyrogram.raw.types.help.CountryCode",
    0xc3878e23: "pyrogram.raw.types.help.Country",
    0x93cc1f32: "pyrogram.raw.types.help.CountriesListNotModified",
    0x87d0759e: "pyrogram.raw.types.help.CountriesList",
    0x455b853d: "pyrogram.raw.types.MessageViews",
    0xb6c4f543: "pyrogram.raw.types.messages.MessageViews",
    0xa6341782: "pyrogram.raw.types.messages.DiscussionMessage",
    0xafbc09db: "pyrogram.raw.types.MessageReplyHeader",
    0xe5af939: "pyrogram.raw.types.MessageReplyStoryHeader",
    0x83d60fc2: "pyrogram.raw.types.MessageReplies",
    0xe8fd8014: "pyrogram.raw.types.PeerBlocked",
    0x7fe91c14: "pyrogram.raw.types.stats.MessageStats",
    0x7780bcb4: "pyrogram.raw.types.GroupCallDiscarded",
    0xd597650c: "pyrogram.raw.types.GroupCall",
    0xd8aa840f: "pyrogram.raw.types.InputGroupCall",
    0xeba636fe: "pyrogram.raw.types.GroupCallParticipant",
    0x9e727aad: "pyrogram.raw.types.phone.GroupCall",
    0xf47751b6: "pyrogram.raw.types.phone.GroupParticipants",
    0x3081ed9d: "pyrogram.raw.types.InlineQueryPeerTypeSameBotPM",
    0x833c0fac: "pyrogram.raw.types.InlineQueryPeerTypePM",
    0xd766c50a: "pyrogram.raw.types.InlineQueryPeerTypeChat",
    0x5ec4be43: "pyrogram.raw.types.InlineQueryPeerTypeMegagroup",
    0x6334ee9a: "pyrogram.raw.types.InlineQueryPeerTypeBroadcast",
    0xe3b2d0c: "pyrogram.raw.types.InlineQueryPeerTypeBotPM",
    0x1662af0b: "pyrogram.raw.types.messages.HistoryImport",
    0x5e0fb7b9: "pyrogram.raw.types.messages.HistoryImportParsed",
    0xef8d3e6c: "pyrogram.raw.types.messages.AffectedFoundMessages",
    0x8c5adfd9: "pyrogram.raw.types.ChatInviteImporter",
    0xbdc62dcc: "pyrogram.raw.types.messages.ExportedChatInvites",
    0x1871be50: "pyrogram.raw.types.messages.ExportedChatInvite",
    0x222600ef: "pyrogram.raw.types.messages.ExportedChatInviteReplaced",
    0x81b6b00a: "pyrogram.raw.types.messages.ChatInviteImporters",
    0xf2ecef23: "pyrogram.raw.types.ChatAdminWithInvites",
    0xb69b72d7: "pyrogram.raw.types.messages.ChatAdminsWithInvites",
    0xa24de717: "pyrogram.raw.types.messages.CheckedHistoryImportPeer",
    0xafe5623f: "pyrogram.raw.types.phone.JoinAsPeers",
    0x204bd158: "pyrogram.raw.types.phone.ExportedGroupCallInvite",
    0xdcb118b7: "pyrogram.raw.types.GroupCallParticipantVideoSourceGroup",
    0x67753ac8: "pyrogram.raw.types.GroupCallParticipantVideo",
    0x85fea03f: "pyrogram.raw.types.stickers.SuggestedShortName",
    0x2f6cb2ab: "pyrogram.raw.types.BotCommandScopeDefault",
    0x3c4f04d8: "pyrogram.raw.types.BotCommandScopeUsers",
    0x6fe1a881: "pyrogram.raw.types.BotCommandScopeChats",
    0xb9aa606a: "pyrogram.raw.types.BotCommandScopeChatAdmins",
    0xdb9d897d: "pyrogram.raw.types.BotCommandScopePeer",
    0x3fd863d1: "pyrogram.raw.types.BotCommandScopePeerAdmins",
    0xa1321f3: "pyrogram.raw.types.BotCommandScopePeerUser",
    0xe3779861: "pyrogram.raw.types.account.ResetPasswordFailedWait",
    0xe9effc7d: "pyrogram.raw.types.account.ResetPasswordRequestedWait",
    0xe926d63e: "pyrogram.raw.types.account.ResetPasswordOk",
    0xed5383f7: "pyrogram.raw.types.SponsoredMessage",
    0xc9ee1d87: "pyrogram.raw.types.messages.SponsoredMessages",
    0x1839490f: "pyrogram.raw.types.messages.SponsoredMessagesEmpty",
    0xc9b0539f: "pyrogram.raw.types.SearchResultsCalendarPeriod",
    0x147ee23c: "pyrogram.raw.types.messages.SearchResultsCalendar",
    0x7f648b67: "pyrogram.raw.types.SearchResultPosition",
    0x53b22baf: "pyrogram.raw.types.messages.SearchResultsPositions",
    0xf496b0c6: "pyrogram.raw.types.channels.SendAsPeers",
    0x3b6d152e: "pyrogram.raw.types.users.UserFull",
    0x6880b94d: "pyrogram.raw.types.messages.PeerSettings",
    0xc3a2835f: "pyrogram.raw.types.auth.LoggedOut",
    0xa3d1cb80: "pyrogram.raw.types.ReactionCount",
    0x4f2b9479: "pyrogram.raw.types.MessageReactions",
    0x31bd492d: "pyrogram.raw.types.messages.MessageReactionsList",
    0xc077ec01: "pyrogram.raw.types.AvailableReaction",
    0x9f071957: "pyrogram.raw.types.messages.AvailableReactionsNotModified",
    0x768e3aad: "pyrogram.raw.types.messages.AvailableReactions",
    0x8c79b63c: "pyrogram.raw.types.MessagePeerReaction",
    0x80eb48af: "pyrogram.raw.types.GroupCallStreamChannel",
    0xd0e482b2: "pyrogram.raw.types.phone.GroupCallStreamChannels",
    0x2dbf3432: "pyrogram.raw.types.phone.GroupCallStreamRtmpUrl",
    0x4576f3f0: "pyrogram.raw.types.AttachMenuBotIconColor",
    0xb2a7386b: "pyrogram.raw.types.AttachMenuBotIcon",
    0xd90d8dfe: "pyrogram.raw.types.AttachMenuBot",
    0xf1d88a5c: "pyrogram.raw.types.AttachMenuBotsNotModified",
    0x3c4301c0: "pyrogram.raw.types.AttachMenuBots",
    0x93bf667f: "pyrogram.raw.types.AttachMenuBotsBot",
    0xc14557c: "pyrogram.raw.types.WebViewResultUrl",
    0x882f76bb: "pyrogram.raw.types.SimpleWebViewResultUrl",
    0xc94511c: "pyrogram.raw.types.WebViewMessageSent",
    0x7533a588: "pyrogram.raw.types.BotMenuButtonDefault",
    0x4258c205: "pyrogram.raw.types.BotMenuButtonCommands",
    0xc7b57ce6: "pyrogram.raw.types.BotMenuButton",
    0xfbf6e8b1: "pyrogram.raw.types.account.SavedRingtonesNotModified",
    0xc1e92cc5: "pyrogram.raw.types.account.SavedRingtones",
    0x97e8bebe: "pyrogram.raw.types.NotificationSoundDefault",
    0x6f0c34df: "pyrogram.raw.types.NotificationSoundNone",
    0x830b9ae4: "pyrogram.raw.types.NotificationSoundLocal",
    0xff6c8049: "pyrogram.raw.types.NotificationSoundRingtone",
    0xb7263f6d: "pyrogram.raw.types.account.SavedRingtone",
    0x1f307eb7: "pyrogram.raw.types.account.SavedRingtoneConverted",
    0x7d6be90e: "pyrogram.raw.types.AttachMenuPeerTypeSameBotPM",
    0xc32bfa1a: "pyrogram.raw.types.AttachMenuPeerTypeBotPM",
    0xf146d31f: "pyrogram.raw.types.AttachMenuPeerTypePM",
    0x509113f: "pyrogram.raw.types.AttachMenuPeerTypeChat",
    0x7bfbdefc: "pyrogram.raw.types.AttachMenuPeerTypeBroadcast",
    0xc5b56859: "pyrogram.raw.types.InputInvoiceMessage",
    0xc326caef: "pyrogram.raw.types.InputInvoiceSlug",
    0x98986c0d: "pyrogram.raw.types.InputInvoicePremiumGiftCode",
    0xaed0cbd9: "pyrogram.raw.types.payments.ExportedInvoice",
    0xcfb9d957: "pyrogram.raw.types.messages.TranscribedAudio",
    0x5334759c: "pyrogram.raw.types.help.PremiumPromo",
    0xa6751e66: "pyrogram.raw.types.InputStorePaymentPremiumSubscription",
    0x616f7fe8: "pyrogram.raw.types.InputStorePaymentGiftPremium",
    0xa3805f3f: "pyrogram.raw.types.InputStorePaymentPremiumGiftCode",
    0x160544ca: "pyrogram.raw.types.InputStorePaymentPremiumGiveaway",
    0x74c34319: "pyrogram.raw.types.PremiumGiftOption",
    0x88f8f21b: "pyrogram.raw.types.PaymentFormMethod",
    0x2de11aae: "pyrogram.raw.types.EmojiStatusEmpty",
    0x929b619d: "pyrogram.raw.types.EmojiStatus",
    0xfa30a8c7: "pyrogram.raw.types.EmojiStatusUntil",
    0xd08ce645: "pyrogram.raw.types.account.EmojiStatusesNotModified",
    0x90c467d1: "pyrogram.raw.types.account.EmojiStatuses",
    0x79f5d419: "pyrogram.raw.types.ReactionEmpty",
    0x1b2286b8: "pyrogram.raw.types.ReactionEmoji",
    0x8935fc73: "pyrogram.raw.types.ReactionCustomEmoji",
    0xeafc32bc: "pyrogram.raw.types.ChatReactionsNone",
    0x52928bca: "pyrogram.raw.types.ChatReactionsAll",
    0x661d4037: "pyrogram.raw.types.ChatReactionsSome",
    0xb06fdbdf: "pyrogram.raw.types.messages.ReactionsNotModified",
    0xeafdf716: "pyrogram.raw.types.messages.Reactions",
    0x4345be73: "pyrogram.raw.types.EmailVerifyPurposeLoginSetup",
    0x527d22eb: "pyrogram.raw.types.EmailVerifyPurposeLoginChange",
    0xbbf51685: "pyrogram.raw.types.EmailVerifyPurposePassport",
    0x922e55a9: "pyrogram.raw.types.EmailVerificationCode",
    0xdb909ec2: "pyrogram.raw.types.EmailVerificationGoogle",
    0x96d074fd: "pyrogram.raw.types.EmailVerificationApple",
    0x2b96cd1b: "pyrogram.raw.types.account.EmailVerified",
    0xe1bb0d61: "pyrogram.raw.types.account.EmailVerifiedLogin",
    0x5f2d1df2: "pyrogram.raw.types.PremiumSubscriptionOption",
    0xb81c7034: "pyrogram.raw.types.SendAsPeer",
    0xad628cc8: "pyrogram.raw.types.MessageExtendedMediaPreview",
    0xee479c64: "pyrogram.raw.types.MessageExtendedMedia",
    0xfcfeb29c: "pyrogram.raw.types.StickerKeyword",
    0xb4073647: "pyrogram.raw.types.Username",
    0x23f109b: "pyrogram.raw.types.ForumTopicDeleted",
    0x71701da9: "pyrogram.raw.types.ForumTopic",
    0x367617d3: "pyrogram.raw.types.messages.ForumTopics",
    0x43b46b20: "pyrogram.raw.types.DefaultHistoryTTL",
    0x41bf109b: "pyrogram.raw.types.ExportedContactToken",
    0x5f3b8a00: "pyrogram.raw.types.RequestPeerTypeUser",
    0xc9f06e1b: "pyrogram.raw.types.RequestPeerTypeChat",
    0x339bef6c: "pyrogram.raw.types.RequestPeerTypeBroadcast",
    0x481eadfa: "pyrogram.raw.types.EmojiListNotModified",
    0x7a1e11d1: "pyrogram.raw.types.EmojiList",
    0x7a9abda9: "pyrogram.raw.types.EmojiGroup",
    0x6fb4ad87: "pyrogram.raw.types.messages.EmojiGroupsNotModified",
    0x881fb94b: "pyrogram.raw.types.messages.EmojiGroups",
    0x751f3146: "pyrogram.raw.types.TextWithEntities",
    0x33db32f8: "pyrogram.raw.types.messages.TranslateResult",
    0xc84834ce: "pyrogram.raw.types.AutoSaveSettings",
    0x81602d47: "pyrogram.raw.types.AutoSaveException",
    0x4c3e069d: "pyrogram.raw.types.account.AutoSaveSettings",
    0x7cde641d: "pyrogram.raw.types.help.AppConfigNotModified",
    0xdd18782e: "pyrogram.raw.types.help.AppConfig",
    0xa920bd7a: "pyrogram.raw.types.InputBotAppID",
    0x908c0407: "pyrogram.raw.types.InputBotAppShortName",
    0x5da674b7: "pyrogram.raw.types.BotAppNotModified",
    0x95fcd1d6: "pyrogram.raw.types.BotApp",
    0xeb50adf5: "pyrogram.raw.types.messages.BotApp",
    0x3c1b4f0d: "pyrogram.raw.types.AppWebViewResultUrl",
    0xb57295d5: "pyrogram.raw.types.InlineBotWebView",
    0x4a4ff172: "pyrogram.raw.types.ReadParticipantDate",
    0xf3e0da33: "pyrogram.raw.types.InputChatlistDialogFilter",
    0xc5181ac: "pyrogram.raw.types.ExportedChatlistInvite",
    0x10e6e3a6: "pyrogram.raw.types.chatlists.ExportedChatlistInvite",
    0x10ab6dc7: "pyrogram.raw.types.chatlists.ExportedInvites",
    0xfa87f659: "pyrogram.raw.types.chatlists.ChatlistInviteAlready",
    0x1dcd839d: "pyrogram.raw.types.chatlists.ChatlistInvite",
    0x93bd878d: "pyrogram.raw.types.chatlists.ChatlistUpdates",
    0xe8a775b0: "pyrogram.raw.types.bots.BotInfo",
    0xb6cc2d5c: "pyrogram.raw.types.MessagePeerVote",
    0x74cda504: "pyrogram.raw.types.MessagePeerVoteInputOption",
    0x4628f6e6: "pyrogram.raw.types.MessagePeerVoteMultiple",
    0x3db8ec63: "pyrogram.raw.types.SponsoredWebPage",
    0x8d595cd6: "pyrogram.raw.types.StoryViews",
    0x51e6ee4f: "pyrogram.raw.types.StoryItemDeleted",
    0xffadc913: "pyrogram.raw.types.StoryItemSkipped",
    0x79b26a24: "pyrogram.raw.types.StoryItem",
    0x1158fe3e: "pyrogram.raw.types.stories.AllStoriesNotModified",
    0x6efc5e81: "pyrogram.raw.types.stories.AllStories",
    0x5dd8c3c8: "pyrogram.raw.types.stories.Stories",
    0xb0bdeac5: "pyrogram.raw.types.StoryView",
    0x9083670b: "pyrogram.raw.types.StoryViewPublicForward",
    0xbd74cf49: "pyrogram.raw.types.StoryViewPublicRepost",
    0x59d78fc5: "pyrogram.raw.types.stories.StoryViewsList",
    0xde9eed1d: "pyrogram.raw.types.stories.StoryViews",
    0x22c0f6d5: "pyrogram.raw.types.InputReplyToMessage",
    0x5881323a: "pyrogram.raw.types.InputReplyToStory",
    0x3fc9053b: "pyrogram.raw.types.ExportedStoryLink",
    0x712e27fd: "pyrogram.raw.types.StoriesStealthMode",
    0x3d1ea4e: "pyrogram.raw.types.MediaAreaCoordinates",
    0xbe82db9c: "pyrogram.raw.types.MediaAreaVenue",
    0xb282217f: "pyrogram.raw.types.InputMediaAreaVenue",
    0xdf8b3b22: "pyrogram.raw.types.MediaAreaGeoPoint",
    0x14455871: "pyrogram.raw.types.MediaAreaSuggestedReaction",
    0x770416af: "pyrogram.raw.types.MediaAreaChannelPost",
    0x2271f2bf: "pyrogram.raw.types.InputMediaAreaChannelPost",
    0x9a35e999: "pyrogram.raw.types.PeerStories",
    0xcae68768: "pyrogram.raw.types.stories.PeerStories",
    0xfd5e12bd: "pyrogram.raw.types.messages.WebPage",
    0x257e962b: "pyrogram.raw.types.PremiumGiftCodeOption",
    0x284a1096: "pyrogram.raw.types.payments.CheckedGiftCode",
    0x4367daa0: "pyrogram.raw.types.payments.GiveawayInfo",
    0xcd5570: "pyrogram.raw.types.payments.GiveawayInfoResults",
    0xb2539d54: "pyrogram.raw.types.PrepaidGiveaway",
    0x2a1c8c71: "pyrogram.raw.types.Boost",
    0x86f8613c: "pyrogram.raw.types.premium.BoostsList",
    0xc448415c: "pyrogram.raw.types.MyBoost",
    0x9ae228e2: "pyrogram.raw.types.premium.MyBoosts",
    0x4959427a: "pyrogram.raw.types.premium.BoostsStatus",
    0xb826e150: "pyrogram.raw.types.StoryFwdHeader",
    0xe7058e7f: "pyrogram.raw.types.PostInteractionCountersMessage",
    0x8a480e27: "pyrogram.raw.types.PostInteractionCountersStory",
    0x50cd067c: "pyrogram.raw.types.stats.StoryStats",
    0x1f2bf4a: "pyrogram.raw.types.PublicForwardMessage",
    0xedf3add0: "pyrogram.raw.types.PublicForwardStory",
    0x93037e20: "pyrogram.raw.types.stats.PublicForwards",
    0xb54b5acf: "pyrogram.raw.types.PeerColor",
    0x26219a58: "pyrogram.raw.types.help.PeerColorSet",
    0x767d61eb: "pyrogram.raw.types.help.PeerColorProfileSet",
    0xadec6ebe: "pyrogram.raw.types.help.PeerColorOption",
    0x2ba1f5ce: "pyrogram.raw.types.help.PeerColorsNotModified",
    0xf8ed08: "pyrogram.raw.types.help.PeerColors",
    0x6090d6d5: "pyrogram.raw.types.StoryReaction",
    0xbbab2643: "pyrogram.raw.types.StoryReactionPublicForward",
    0xcfcd0f13: "pyrogram.raw.types.StoryReactionPublicRepost",
    0xaa5f789c: "pyrogram.raw.types.stories.StoryReactionsList",
    0xbd87cb6c: "pyrogram.raw.types.SavedDialog",
    0xf83ae221: "pyrogram.raw.types.messages.SavedDialogs",
    0x44ba9dd9: "pyrogram.raw.types.messages.SavedDialogsSlice",
    0xc01f6fe8: "pyrogram.raw.types.messages.SavedDialogsNotModified",
    0xcb6ff828: "pyrogram.raw.types.SavedReactionTag",
    0x889b59ef: "pyrogram.raw.types.messages.SavedReactionTagsNotModified",
    0x3259950a: "pyrogram.raw.types.messages.SavedReactionTags",
    0x3bb842ac: "pyrogram.raw.types.OutboxReadDate",
    0xdc8b44cf: "pyrogram.raw.types.smsjobs.EligibleToJoin",
    0x2aee9191: "pyrogram.raw.types.smsjobs.Status",
    0xe6a1eeb8: "pyrogram.raw.types.SmsJob",
    0x120b1ab9: "pyrogram.raw.types.BusinessWeeklyOpen",
    0x8c92b098: "pyrogram.raw.types.BusinessWorkHours",
    0xac5c1af7: "pyrogram.raw.types.BusinessLocation",
    0x6f8b32aa: "pyrogram.raw.types.InputBusinessRecipients",
    0x21108ff7: "pyrogram.raw.types.BusinessRecipients",
    0xc9b9e2b9: "pyrogram.raw.types.BusinessAwayMessageScheduleAlways",
    0xc3f2f501: "pyrogram.raw.types.BusinessAwayMessageScheduleOutsideWorkHours",
    0xcc4d9ecc: "pyrogram.raw.types.BusinessAwayMessageScheduleCustom",
    0x194cb3b: "pyrogram.raw.types.InputBusinessGreetingMessage",
    0xe519abab: "pyrogram.raw.types.BusinessGreetingMessage",
    0x832175e0: "pyrogram.raw.types.InputBusinessAwayMessage",
    0xef156a5c: "pyrogram.raw.types.BusinessAwayMessage",
    0xff9289f5: "pyrogram.raw.types.Timezone",
    0x970708cc: "pyrogram.raw.types.help.TimezonesListNotModified",
    0x7b74ed71: "pyrogram.raw.types.help.TimezonesList",
    0x697102b: "pyrogram.raw.types.QuickReply",
    0x24596d41: "pyrogram.raw.types.InputQuickReplyShortcut",
    0x1190cf1: "pyrogram.raw.types.InputQuickReplyShortcutId",
    0xc68d6695: "pyrogram.raw.types.messages.QuickReplies",
    0x5f91eb5b: "pyrogram.raw.types.messages.QuickRepliesNotModified",
    0xbd068601: "pyrogram.raw.types.ConnectedBot",
    0x17d7f87b: "pyrogram.raw.types.account.ConnectedBots",
    0x2ad93719: "pyrogram.raw.types.messages.DialogFilters",
    0x6c8e1e06: "pyrogram.raw.types.Birthday",
    0x896433b4: "pyrogram.raw.types.BotBusinessConnection",
    0x9c469cd: "pyrogram.raw.types.InputBusinessIntro",
    0x5a0a066d: "pyrogram.raw.types.BusinessIntro",
    0xfaff629d: "pyrogram.raw.types.messages.MyStickers",
    0xe39460a9: "pyrogram.raw.types.InputCollectibleUsername",
    0xa2e214a4: "pyrogram.raw.types.InputCollectiblePhone",
    0x6ebdff91: "pyrogram.raw.types.fragment.CollectibleInfo",
    0xc4e5921e: "pyrogram.raw.types.InputBusinessBotRecipients",
    0xb88cf373: "pyrogram.raw.types.BusinessBotRecipients",
    0x1d998733: "pyrogram.raw.types.ContactBirthday",
    0x114ff30d: "pyrogram.raw.types.contacts.ContactBirthdays",
    0x628c9224: "pyrogram.raw.types.MissingInvitee",
    0x7f5defa6: "pyrogram.raw.types.messages.InvitedUsers",
    0x11679fa7: "pyrogram.raw.types.InputBusinessChatLink",
    0xb4ae666f: "pyrogram.raw.types.BusinessChatLink",
    0xec43a2d1: "pyrogram.raw.types.account.BusinessChatLinks",
    0x9a23af21: "pyrogram.raw.types.account.ResolvedBusinessChatLinks",
    0xd62ff46a: "pyrogram.raw.types.RequestedPeerUser",
    0x7307544f: "pyrogram.raw.types.RequestedPeerChat",
    0x8ba403e4: "pyrogram.raw.types.RequestedPeerChannel",
    0x430d3150: "pyrogram.raw.types.SponsoredMessageReportOption",
    0x846f9e42: "pyrogram.raw.types.channels.SponsoredMessageReportResultChooseOption",
    0x3e3bcf2f: "pyrogram.raw.types.channels.SponsoredMessageReportResultAdsHidden",
    0xad798849: "pyrogram.raw.types.channels.SponsoredMessageReportResultReported",
    0xd07b4bad: "pyrogram.raw.types.stats.BroadcastRevenueStats",
    0xec659737: "pyrogram.raw.types.stats.BroadcastRevenueWithdrawalUrl",
    0x557e2cc4: "pyrogram.raw.types.BroadcastRevenueTransactionProceeds",
    0x5a590978: "pyrogram.raw.types.BroadcastRevenueTransactionWithdrawal",
    0x42d30d2e: "pyrogram.raw.types.BroadcastRevenueTransactionRefund",
    0x87158466: "pyrogram.raw.types.stats.BroadcastRevenueTransactions",
    0xcb9f372d: "pyrogram.raw.functions.InvokeAfterMsg",
    0x3dc4b4f0: "pyrogram.raw.functions.InvokeAfterMsgs",
    0xc1cd5ea9: "pyrogram.raw.functions.InitConnection",
    0xda9b0d0d: "pyrogram.raw.functions.InvokeWithLayer",
    0xbf9459b7: "pyrogram.raw.functions.InvokeWithoutUpdates",
    0x365275f2: "pyrogram.raw.functions.InvokeWithMessagesRange",
    0xaca9fd2e: "pyrogram.raw.functions.InvokeWithTakeout",
    0xdd289f8e: "pyrogram.raw.functions.InvokeWithBusinessConnection",
    0xa677244f: "pyrogram.raw.functions.auth.SendCode",
    0xaac7b717: "pyrogram.raw.functions.auth.SignUp",
    0x8d52a951: "pyrogram.raw.functions.auth.SignIn",
    0x3e72ba19: "pyrogram.raw.functions.auth.LogOut",
    0x9fab0d1a: "pyrogram.raw.functions.auth.ResetAuthorizations",
    0xe5bfffcd: "pyrogram.raw.functions.auth.ExportAuthorization",
    0xa57a7dad: "pyrogram.raw.functions.auth.ImportAuthorization",
    0xcdd42a05: "pyrogram.raw.functions.auth.BindTempAuthKey",
    0x67a3ff2c: "pyrogram.raw.functions.auth.ImportBotAuthorization",
    0xd18b4d16: "pyrogram.raw.functions.auth.CheckPassword",
    0xd897bc66: "pyrogram.raw.functions.auth.RequestPasswordRecovery",
    0x37096c70: "pyrogram.raw.functions.auth.RecoverPassword",
    0x3ef1a9bf: "pyrogram.raw.functions.auth.ResendCode",
    0x1f040578: "pyrogram.raw.functions.auth.CancelCode",
    0x8e48a188: "pyrogram.raw.functions.auth.DropTempAuthKeys",
    0xb7e085fe: "pyrogram.raw.functions.auth.ExportLoginToken",
    0x95ac5ce4: "pyrogram.raw.functions.auth.ImportLoginToken",
    0xe894ad4d: "pyrogram.raw.functions.auth.AcceptLoginToken",
    0xd36bf79: "pyrogram.raw.functions.auth.CheckRecoveryPassword",
    0x2db873a9: "pyrogram.raw.functions.auth.ImportWebTokenAuthorization",
    0x89464b50: "pyrogram.raw.functions.auth.RequestFirebaseSms",
    0x7e960193: "pyrogram.raw.functions.auth.ResetLoginEmail",
    0xec86017a: "pyrogram.raw.functions.account.RegisterDevice",
    0x6a0d3206: "pyrogram.raw.functions.account.UnregisterDevice",
    0x84be5b93: "pyrogram.raw.functions.account.UpdateNotifySettings",
    0x12b3ad31: "pyrogram.raw.functions.account.GetNotifySettings",
    0xdb7e1747: "pyrogram.raw.functions.account.ResetNotifySettings",
    0x78515775: "pyrogram.raw.functions.account.UpdateProfile",
    0x6628562c: "pyrogram.raw.functions.account.UpdateStatus",
    0x7967d36: "pyrogram.raw.functions.account.GetWallPapers",
    0xc5ba3d86: "pyrogram.raw.functions.account.ReportPeer",
    0x2714d86c: "pyrogram.raw.functions.account.CheckUsername",
    0x3e0bdd7c: "pyrogram.raw.functions.account.UpdateUsername",
    0xdadbc950: "pyrogram.raw.functions.account.GetPrivacy",
    0xc9f81ce8: "pyrogram.raw.functions.account.SetPrivacy",
    0xa2c0cf74: "pyrogram.raw.functions.account.DeleteAccount",
    0x8fc711d: "pyrogram.raw.functions.account.GetAccountTTL",
    0x2442485e: "pyrogram.raw.functions.account.SetAccountTTL",
    0x82574ae5: "pyrogram.raw.functions.account.SendChangePhoneCode",
    0x70c32edb: "pyrogram.raw.functions.account.ChangePhone",
    0x38df3532: "pyrogram.raw.functions.account.UpdateDeviceLocked",
    0xe320c158: "pyrogram.raw.functions.account.GetAuthorizations",
    0xdf77f3bc: "pyrogram.raw.functions.account.ResetAuthorization",
    0x548a30f5: "pyrogram.raw.functions.account.GetPassword",
    0x9cd4eaf9: "pyrogram.raw.functions.account.GetPasswordSettings",
    0xa59b102f: "pyrogram.raw.functions.account.UpdatePasswordSettings",
    0x1b3faa88: "pyrogram.raw.functions.account.SendConfirmPhoneCode",
    0x5f2178c3: "pyrogram.raw.functions.account.ConfirmPhone",
    0x449e0b51: "pyrogram.raw.functions.account.GetTmpPassword",
    0x182e6d6f: "pyrogram.raw.functions.account.GetWebAuthorizations",
    0x2d01b9ef: "pyrogram.raw.functions.account.ResetWebAuthorization",
    0x682d2594: "pyrogram.raw.functions.account.ResetWebAuthorizations",
    0xb288bc7d: "pyrogram.raw.functions.account.GetAllSecureValues",
    0x73665bc2: "pyrogram.raw.functions.account.GetSecureValue",
    0x899fe31d: "pyrogram.raw.functions.account.SaveSecureValue",
    0xb880bc4b: "pyrogram.raw.functions.account.DeleteSecureValue",
    0xa929597a: "pyrogram.raw.functions.account.GetAuthorizationForm",
    0xf3ed4c73: "pyrogram.raw.functions.account.AcceptAuthorization",
    0xa5a356f9: "pyrogram.raw.functions.account.SendVerifyPhoneCode",
    0x4dd3a7f6: "pyrogram.raw.functions.account.VerifyPhone",
    0x98e037bb: "pyrogram.raw.functions.account.SendVerifyEmailCode",
    0x32da4cf: "pyrogram.raw.functions.account.VerifyEmail",
    0x8ef3eab0: "pyrogram.raw.functions.account.InitTakeoutSession",
    0x1d2652ee: "pyrogram.raw.functions.account.FinishTakeoutSession",
    0x8fdf1920: "pyrogram.raw.functions.account.ConfirmPasswordEmail",
    0x7a7f2a15: "pyrogram.raw.functions.account.ResendPasswordEmail",
    0xc1cbd5b6: "pyrogram.raw.functions.account.CancelPasswordEmail",
    0x9f07c728: "pyrogram.raw.functions.account.GetContactSignUpNotification",
    0xcff43f61: "pyrogram.raw.functions.account.SetContactSignUpNotification",
    0x53577479: "pyrogram.raw.functions.account.GetNotifyExceptions",
    0xfc8ddbea: "pyrogram.raw.functions.account.GetWallPaper",
    0xe39a8f03: "pyrogram.raw.functions.account.UploadWallPaper",
    0x6c5a5b37: "pyrogram.raw.functions.account.SaveWallPaper",
    0xfeed5769: "pyrogram.raw.functions.account.InstallWallPaper",
    0xbb3b9804: "pyrogram.raw.functions.account.ResetWallPapers",
    0x56da0b3f: "pyrogram.raw.functions.account.GetAutoDownloadSettings",
    0x76f36233: "pyrogram.raw.functions.account.SaveAutoDownloadSettings",
    0x1c3db333: "pyrogram.raw.functions.account.UploadTheme",
    0x652e4400: "pyrogram.raw.functions.account.CreateTheme",
    0x2bf40ccc: "pyrogram.raw.functions.account.UpdateTheme",
    0xf257106c: "pyrogram.raw.functions.account.SaveTheme",
    0xc727bb3b: "pyrogram.raw.functions.account.InstallTheme",
    0x3a5869ec: "pyrogram.raw.functions.account.GetTheme",
    0x7206e458: "pyrogram.raw.functions.account.GetThemes",
    0xb574b16b: "pyrogram.raw.functions.account.SetContentSettings",
    0x8b9b4dae: "pyrogram.raw.functions.account.GetContentSettings",
    0x65ad71dc: "pyrogram.raw.functions.account.GetMultiWallPapers",
    0xeb2b4cf6: "pyrogram.raw.functions.account.GetGlobalPrivacySettings",
    0x1edaaac2: "pyrogram.raw.functions.account.SetGlobalPrivacySettings",
    0xfa8cc6f5: "pyrogram.raw.functions.account.ReportProfilePhoto",
    0x9308ce1b: "pyrogram.raw.functions.account.ResetPassword",
    0x4c9409f6: "pyrogram.raw.functions.account.DeclinePasswordReset",
    0xd638de89: "pyrogram.raw.functions.account.GetChatThemes",
    0xbf899aa0: "pyrogram.raw.functions.account.SetAuthorizationTTL",
    0x40f48462: "pyrogram.raw.functions.account.ChangeAuthorizationSettings",
    0xe1902288: "pyrogram.raw.functions.account.GetSavedRingtones",
    0x3dea5b03: "pyrogram.raw.functions.account.SaveRingtone",
    0x831a83a2: "pyrogram.raw.functions.account.UploadRingtone",
    0xfbd3de6b: "pyrogram.raw.functions.account.UpdateEmojiStatus",
    0xd6753386: "pyrogram.raw.functions.account.GetDefaultEmojiStatuses",
    0xf578105: "pyrogram.raw.functions.account.GetRecentEmojiStatuses",
    0x18201aae: "pyrogram.raw.functions.account.ClearRecentEmojiStatuses",
    0xef500eab: "pyrogram.raw.functions.account.ReorderUsernames",
    0x58d6b376: "pyrogram.raw.functions.account.ToggleUsername",
    0xe2750328: "pyrogram.raw.functions.account.GetDefaultProfilePhotoEmojis",
    0x915860ae: "pyrogram.raw.functions.account.GetDefaultGroupPhotoEmojis",
    0xadcbbcda: "pyrogram.raw.functions.account.GetAutoSaveSettings",
    0xd69b8361: "pyrogram.raw.functions.account.SaveAutoSaveSettings",
    0x53bc0020: "pyrogram.raw.functions.account.DeleteAutoSaveExceptions",
    0xca8ae8ba: "pyrogram.raw.functions.account.InvalidateSignInCodes",
    0x7cefa15d: "pyrogram.raw.functions.account.UpdateColor",
    0xa60ab9ce: "pyrogram.raw.functions.account.GetDefaultBackgroundEmojis",
    0x7727a7d5: "pyrogram.raw.functions.account.GetChannelDefaultEmojiStatuses",
    0x35a9e0d5: "pyrogram.raw.functions.account.GetChannelRestrictedStatusEmojis",
    0x4b00e066: "pyrogram.raw.functions.account.UpdateBusinessWorkHours",
    0x9e6b131a: "pyrogram.raw.functions.account.UpdateBusinessLocation",
    0x66cdafc4: "pyrogram.raw.functions.account.UpdateBusinessGreetingMessage",
    0xa26a7fa5: "pyrogram.raw.functions.account.UpdateBusinessAwayMessage",
    0x43d8521d: "pyrogram.raw.functions.account.UpdateConnectedBot",
    0x4ea4c80f: "pyrogram.raw.functions.account.GetConnectedBots",
    0x76a86270: "pyrogram.raw.functions.account.GetBotBusinessConnection",
    0xa614d034: "pyrogram.raw.functions.account.UpdateBusinessIntro",
    0x646e1097: "pyrogram.raw.functions.account.ToggleConnectedBotPaused",
    0x5e437ed9: "pyrogram.raw.functions.account.DisablePeerConnectedBot",
    0xcc6e0c11: "pyrogram.raw.functions.account.UpdateBirthday",
    0x8851e68e: "pyrogram.raw.functions.account.CreateBusinessChatLink",
    0x8c3410af: "pyrogram.raw.functions.account.EditBusinessChatLink",
    0x60073674: "pyrogram.raw.functions.account.DeleteBusinessChatLink",
    0x6f70dde1: "pyrogram.raw.functions.account.GetBusinessChatLinks",
    0x5492e5ee: "pyrogram.raw.functions.account.ResolveBusinessChatLink",
    0xd94305e0: "pyrogram.raw.functions.account.UpdatePersonalChannel",
    0xd91a548: "pyrogram.raw.functions.users.GetUsers",
    0xb60f5918: "pyrogram.raw.functions.users.GetFullUser",
    0x90c894b5: "pyrogram.raw.functions.users.SetSecureValueErrors",
    0xa622aa10: "pyrogram.raw.functions.users.GetIsPremiumRequiredToContact",
    0x7adc669d: "pyrogram.raw.functions.contacts.GetContactIDs",
    0xc4a353ee: "pyrogram.raw.functions.contacts.GetStatuses",
    0x5dd69e12: "pyrogram.raw.functions.contacts.GetContacts",
    0x2c800be5: "pyrogram.raw.functions.contacts.ImportContacts",
    0x96a0e00: "pyrogram.raw.functions.contacts.DeleteContacts",
    0x1013fd9e: "pyrogram.raw.functions.contacts.DeleteByPhones",
    0x2e2e8734: "pyrogram.raw.functions.contacts.Block",
    0xb550d328: "pyrogram.raw.functions.contacts.Unblock",
    0x9a868f80: "pyrogram.raw.functions.contacts.GetBlocked",
    0x11f812d8: "pyrogram.raw.functions.contacts.Search",
    0xf93ccba3: "pyrogram.raw.functions.contacts.ResolveUsername",
    0x973478b6: "pyrogram.raw.functions.contacts.GetTopPeers",
    0x1ae373ac: "pyrogram.raw.functions.contacts.ResetTopPeerRating",
    0x879537f1: "pyrogram.raw.functions.contacts.ResetSaved",
    0x82f1e39f: "pyrogram.raw.functions.contacts.GetSaved",
    0x8514bdda: "pyrogram.raw.functions.contacts.ToggleTopPeers",
    0xe8f463d0: "pyrogram.raw.functions.contacts.AddContact",
    0xf831a20f: "pyrogram.raw.functions.contacts.AcceptContact",
    0xd348bc44: "pyrogram.raw.functions.contacts.GetLocated",
    0x29a8962c: "pyrogram.raw.functions.contacts.BlockFromReplies",
    0x8af94344: "pyrogram.raw.functions.contacts.ResolvePhone",
    0xf8654027: "pyrogram.raw.functions.contacts.ExportContactToken",
    0x13005788: "pyrogram.raw.functions.contacts.ImportContactToken",
    0xba6705f0: "pyrogram.raw.functions.contacts.EditCloseFriends",
    0x94c65c76: "pyrogram.raw.functions.contacts.SetBlocked",
    0xdaeda864: "pyrogram.raw.functions.contacts.GetBirthdays",
    0x63c66506: "pyrogram.raw.functions.messages.GetMessages",
    0xa0f4cb4f: "pyrogram.raw.functions.messages.GetDialogs",
    0x4423e6c5: "pyrogram.raw.functions.messages.GetHistory",
    0x29ee847a: "pyrogram.raw.functions.messages.Search",
    0xe306d3a: "pyrogram.raw.functions.messages.ReadHistory",
    0xb08f922a: "pyrogram.raw.functions.messages.DeleteHistory",
    0xe58e95d2: "pyrogram.raw.functions.messages.DeleteMessages",
    0x5a954c0: "pyrogram.raw.functions.messages.ReceivedMessages",
    0x58943ee2: "pyrogram.raw.functions.messages.SetTyping",
    0xdff8042c: "pyrogram.raw.functions.messages.SendMessage",
    0x7bd66041: "pyrogram.raw.functions.messages.SendMedia",
    0xd5039208: "pyrogram.raw.functions.messages.ForwardMessages",
    0xcf1592db: "pyrogram.raw.functions.messages.ReportSpam",
    0xefd9a6a2: "pyrogram.raw.functions.messages.GetPeerSettings",
    0x8953ab4e: "pyrogram.raw.functions.messages.Report",
    0x49e9528f: "pyrogram.raw.functions.messages.GetChats",
    0xaeb00b34: "pyrogram.raw.functions.messages.GetFullChat",
    0x73783ffd: "pyrogram.raw.functions.messages.EditChatTitle",
    0x35ddd674: "pyrogram.raw.functions.messages.EditChatPhoto",
    0xcbc6d107: "pyrogram.raw.functions.messages.AddChatUser",
    0xa2185cab: "pyrogram.raw.functions.messages.DeleteChatUser",
    0x92ceddd4: "pyrogram.raw.functions.messages.CreateChat",
    0x26cf8950: "pyrogram.raw.functions.messages.GetDhConfig",
    0xf64daf43: "pyrogram.raw.functions.messages.RequestEncryption",
    0x3dbc0415: "pyrogram.raw.functions.messages.AcceptEncryption",
    0xf393aea0: "pyrogram.raw.functions.messages.DiscardEncryption",
    0x791451ed: "pyrogram.raw.functions.messages.SetEncryptedTyping",
    0x7f4b690a: "pyrogram.raw.functions.messages.ReadEncryptedHistory",
    0x44fa7a15: "pyrogram.raw.functions.messages.SendEncrypted",
    0x5559481d: "pyrogram.raw.functions.messages.SendEncryptedFile",
    0x32d439a4: "pyrogram.raw.functions.messages.SendEncryptedService",
    0x55a5bb66: "pyrogram.raw.functions.messages.ReceivedQueue",
    0x4b0c8c0f: "pyrogram.raw.functions.messages.ReportEncryptedSpam",
    0x36a73f77: "pyrogram.raw.functions.messages.ReadMessageContents",
    0xd5a5d3a1: "pyrogram.raw.functions.messages.GetStickers",
    0xb8a0a1a8: "pyrogram.raw.functions.messages.GetAllStickers",
    0x8b68b0cc: "pyrogram.raw.functions.messages.GetWebPagePreview",
    0xa02ce5d5: "pyrogram.raw.functions.messages.ExportChatInvite",
    0x3eadb1bb: "pyrogram.raw.functions.messages.CheckChatInvite",
    0x6c50051c: "pyrogram.raw.functions.messages.ImportChatInvite",
    0xc8a0ec74: "pyrogram.raw.functions.messages.GetStickerSet",
    0xc78fe460: "pyrogram.raw.functions.messages.InstallStickerSet",
    0xf96e55de: "pyrogram.raw.functions.messages.UninstallStickerSet",
    0xe6df7378: "pyrogram.raw.functions.messages.StartBot",
    0x5784d3e1: "pyrogram.raw.functions.messages.GetMessagesViews",
    0xa85bd1c2: "pyrogram.raw.functions.messages.EditChatAdmin",
    0xa2875319: "pyrogram.raw.functions.messages.MigrateChat",
    0x4bc6589a: "pyrogram.raw.functions.messages.SearchGlobal",
    0x78337739: "pyrogram.raw.functions.messages.ReorderStickerSets",
    0xb1f2061f: "pyrogram.raw.functions.messages.GetDocumentByHash",
    0x5cf09635: "pyrogram.raw.functions.messages.GetSavedGifs",
    0x327a30cb: "pyrogram.raw.functions.messages.SaveGif",
    0x514e999d: "pyrogram.raw.functions.messages.GetInlineBotResults",
    0xbb12a419: "pyrogram.raw.functions.messages.SetInlineBotResults",
    0x3ebee86a: "pyrogram.raw.functions.messages.SendInlineBotResult",
    0xfda68d36: "pyrogram.raw.functions.messages.GetMessageEditData",
    0xdfd14005: "pyrogram.raw.functions.messages.EditMessage",
    0x83557dba: "pyrogram.raw.functions.messages.EditInlineBotMessage",
    0x9342ca07: "pyrogram.raw.functions.messages.GetBotCallbackAnswer",
    0xd58f130a: "pyrogram.raw.functions.messages.SetBotCallbackAnswer",
    0xe470bcfd: "pyrogram.raw.functions.messages.GetPeerDialogs",
    0x7ff3b806: "pyrogram.raw.functions.messages.SaveDraft",
    0x6a3f8d65: "pyrogram.raw.functions.messages.GetAllDrafts",
    0x64780b14: "pyrogram.raw.functions.messages.GetFeaturedStickers",
    0x5b118126: "pyrogram.raw.functions.messages.ReadFeaturedStickers",
    0x9da9403b: "pyrogram.raw.functions.messages.GetRecentStickers",
    0x392718f8: "pyrogram.raw.functions.messages.SaveRecentSticker",
    0x8999602d: "pyrogram.raw.functions.messages.ClearRecentStickers",
    0x57f17692: "pyrogram.raw.functions.messages.GetArchivedStickers",
    0x640f82b8: "pyrogram.raw.functions.messages.GetMaskStickers",
    0xcc5b67cc: "pyrogram.raw.functions.messages.GetAttachedStickers",
    0x8ef8ecc0: "pyrogram.raw.functions.messages.SetGameScore",
    0x15ad9f64: "pyrogram.raw.functions.messages.SetInlineGameScore",
    0xe822649d: "pyrogram.raw.functions.messages.GetGameHighScores",
    0xf635e1b: "pyrogram.raw.functions.messages.GetInlineGameHighScores",
    0xe40ca104: "pyrogram.raw.functions.messages.GetCommonChats",
    0x8d9692a3: "pyrogram.raw.functions.messages.GetWebPage",
    0xa731e257: "pyrogram.raw.functions.messages.ToggleDialogPin",
    0x3b1adf37: "pyrogram.raw.functions.messages.ReorderPinnedDialogs",
    0xd6b94df2: "pyrogram.raw.functions.messages.GetPinnedDialogs",
    0xe5f672fa: "pyrogram.raw.functions.messages.SetBotShippingResults",
    0x9c2dd95: "pyrogram.raw.functions.messages.SetBotPrecheckoutResults",
    0x14967978: "pyrogram.raw.functions.messages.UploadMedia",
    0xa1405817: "pyrogram.raw.functions.messages.SendScreenshotNotification",
    0x4f1aaa9: "pyrogram.raw.functions.messages.GetFavedStickers",
    0xb9ffc55b: "pyrogram.raw.functions.messages.FaveSticker",
    0xf107e790: "pyrogram.raw.functions.messages.GetUnreadMentions",
    0x36e5bf4d: "pyrogram.raw.functions.messages.ReadMentions",
    0x702a40e0: "pyrogram.raw.functions.messages.GetRecentLocations",
    0xc964709: "pyrogram.raw.functions.messages.SendMultiMedia",
    0x5057c497: "pyrogram.raw.functions.messages.UploadEncryptedFile",
    0x35705b8a: "pyrogram.raw.functions.messages.SearchStickerSets",
    0x1cff7e08: "pyrogram.raw.functions.messages.GetSplitRanges",
    0xc286d98f: "pyrogram.raw.functions.messages.MarkDialogUnread",
    0x22e24e22: "pyrogram.raw.functions.messages.GetDialogUnreadMarks",
    0x7e58ee9c: "pyrogram.raw.functions.messages.ClearAllDrafts",
    0xd2aaf7ec: "pyrogram.raw.functions.messages.UpdatePinnedMessage",
    0x10ea6184: "pyrogram.raw.functions.messages.SendVote",
    0x73bb643b: "pyrogram.raw.functions.messages.GetPollResults",
    0x6e2be050: "pyrogram.raw.functions.messages.GetOnlines",
    0xdef60797: "pyrogram.raw.functions.messages.EditChatAbout",
    0xa5866b41: "pyrogram.raw.functions.messages.EditChatDefaultBannedRights",
    0x35a0e062: "pyrogram.raw.functions.messages.GetEmojiKeywords",
    0x1508b6af: "pyrogram.raw.functions.messages.GetEmojiKeywordsDifference",
    0x4e9963b2: "pyrogram.raw.functions.messages.GetEmojiKeywordsLanguages",
    0xd5b10c26: "pyrogram.raw.functions.messages.GetEmojiURL",
    0x1bbcf300: "pyrogram.raw.functions.messages.GetSearchCounters",
    0x198fb446: "pyrogram.raw.functions.messages.RequestUrlAuth",
    0xb12c7125: "pyrogram.raw.functions.messages.AcceptUrlAuth",
    0x4facb138: "pyrogram.raw.functions.messages.HidePeerSettingsBar",
    0xf516760b: "pyrogram.raw.functions.messages.GetScheduledHistory",
    0xbdbb0464: "pyrogram.raw.functions.messages.GetScheduledMessages",
    0xbd38850a: "pyrogram.raw.functions.messages.SendScheduledMessages",
    0x59ae2b16: "pyrogram.raw.functions.messages.DeleteScheduledMessages",
    0xb86e380e: "pyrogram.raw.functions.messages.GetPollVotes",
    0xb5052fea: "pyrogram.raw.functions.messages.ToggleStickerSets",
    0xefd48c89: "pyrogram.raw.functions.messages.GetDialogFilters",
    0xa29cd42c: "pyrogram.raw.functions.messages.GetSuggestedDialogFilters",
    0x1ad4a04a: "pyrogram.raw.functions.messages.UpdateDialogFilter",
    0xc563c1e4: "pyrogram.raw.functions.messages.UpdateDialogFiltersOrder",
    0x7ed094a1: "pyrogram.raw.functions.messages.GetOldFeaturedStickers",
    0x22ddd30c: "pyrogram.raw.functions.messages.GetReplies",
    0x446972fd: "pyrogram.raw.functions.messages.GetDiscussionMessage",
    0xf731a9f4: "pyrogram.raw.functions.messages.ReadDiscussion",
    0xee22b9a8: "pyrogram.raw.functions.messages.UnpinAllMessages",
    0x5bd0ee50: "pyrogram.raw.functions.messages.DeleteChat",
    0xf9cbe409: "pyrogram.raw.functions.messages.DeletePhoneCallHistory",
    0x43fe19f3: "pyrogram.raw.functions.messages.CheckHistoryImport",
    0x34090c3b: "pyrogram.raw.functions.messages.InitHistoryImport",
    0x2a862092: "pyrogram.raw.functions.messages.UploadImportedMedia",
    0xb43df344: "pyrogram.raw.functions.messages.StartHistoryImport",
    0xa2b5a3f6: "pyrogram.raw.functions.messages.GetExportedChatInvites",
    0x73746f5c: "pyrogram.raw.functions.messages.GetExportedChatInvite",
    0xbdca2f75: "pyrogram.raw.functions.messages.EditExportedChatInvite",
    0x56987bd5: "pyrogram.raw.functions.messages.DeleteRevokedExportedChatInvites",
    0xd464a42b: "pyrogram.raw.functions.messages.DeleteExportedChatInvite",
    0x3920e6ef: "pyrogram.raw.functions.messages.GetAdminsWithInvites",
    0xdf04dd4e: "pyrogram.raw.functions.messages.GetChatInviteImporters",
    0xb80e5fe4: "pyrogram.raw.functions.messages.SetHistoryTTL",
    0x5dc60f03: "pyrogram.raw.functions.messages.CheckHistoryImportPeer",
    0xe63be13f: "pyrogram.raw.functions.messages.SetChatTheme",
    0x31c1c44f: "pyrogram.raw.functions.messages.GetMessageReadParticipants",
    0x6aa3f6bd: "pyrogram.raw.functions.messages.GetSearchResultsCalendar",
    0x9c7f2f10: "pyrogram.raw.functions.messages.GetSearchResultsPositions",
    0x7fe7e815: "pyrogram.raw.functions.messages.HideChatJoinRequest",
    0xe085f4ea: "pyrogram.raw.functions.messages.HideAllChatJoinRequests",
    0xb11eafa2: "pyrogram.raw.functions.messages.ToggleNoForwards",
    0xccfddf96: "pyrogram.raw.functions.messages.SaveDefaultSendAs",
    0xd30d78d4: "pyrogram.raw.functions.messages.SendReaction",
    0x8bba90e6: "pyrogram.raw.functions.messages.GetMessagesReactions",
    0x461b3f48: "pyrogram.raw.functions.messages.GetMessageReactionsList",
    0xfeb16771: "pyrogram.raw.functions.messages.SetChatAvailableReactions",
    0x18dea0ac: "pyrogram.raw.functions.messages.GetAvailableReactions",
    0x4f47a016: "pyrogram.raw.functions.messages.SetDefaultReaction",
    0x63183030: "pyrogram.raw.functions.messages.TranslateText",
    0x3223495b: "pyrogram.raw.functions.messages.GetUnreadReactions",
    0x54aa7f8e: "pyrogram.raw.functions.messages.ReadReactions",
    0x107e31a0: "pyrogram.raw.functions.messages.SearchSentMedia",
    0x16fcc2cb: "pyrogram.raw.functions.messages.GetAttachMenuBots",
    0x77216192: "pyrogram.raw.functions.messages.GetAttachMenuBot",
    0x69f59d69: "pyrogram.raw.functions.messages.ToggleBotInAttachMenu",
    0x269dc2c1: "pyrogram.raw.functions.messages.RequestWebView",
    0xb0d81a83: "pyrogram.raw.functions.messages.ProlongWebView",
    0x1a46500a: "pyrogram.raw.functions.messages.RequestSimpleWebView",
    0xa4314f5: "pyrogram.raw.functions.messages.SendWebViewResultMessage",
    0xdc0242c8: "pyrogram.raw.functions.messages.SendWebViewData",
    0x269e9a49: "pyrogram.raw.functions.messages.TranscribeAudio",
    0x7f1d072f: "pyrogram.raw.functions.messages.RateTranscribedAudio",
    0xd9ab0f54: "pyrogram.raw.functions.messages.GetCustomEmojiDocuments",
    0xfbfca18f: "pyrogram.raw.functions.messages.GetEmojiStickers",
    0xecf6736: "pyrogram.raw.functions.messages.GetFeaturedEmojiStickers",
    0x3f64c076: "pyrogram.raw.functions.messages.ReportReaction",
    0xbb8125ba: "pyrogram.raw.functions.messages.GetTopReactions",
    0x39461db2: "pyrogram.raw.functions.messages.GetRecentReactions",
    0x9dfeefb4: "pyrogram.raw.functions.messages.ClearRecentReactions",
    0x84f80814: "pyrogram.raw.functions.messages.GetExtendedMedia",
    0x9eb51445: "pyrogram.raw.functions.messages.SetDefaultHistoryTTL",
    0x658b7188: "pyrogram.raw.functions.messages.GetDefaultHistoryTTL",
    0x91b2d060: "pyrogram.raw.functions.messages.SendBotRequestedPeer",
    0x7488ce5b: "pyrogram.raw.functions.messages.GetEmojiGroups",
    0x2ecd56cd: "pyrogram.raw.functions.messages.GetEmojiStatusGroups",
    0x21a548f3: "pyrogram.raw.functions.messages.GetEmojiProfilePhotoGroups",
    0x2c11c0d7: "pyrogram.raw.functions.messages.SearchCustomEmoji",
    0xe47cb579: "pyrogram.raw.functions.messages.TogglePeerTranslations",
    0x34fdc5c3: "pyrogram.raw.functions.messages.GetBotApp",
    0x8c5a3b3c: "pyrogram.raw.functions.messages.RequestAppWebView",
    0x8ffacae1: "pyrogram.raw.functions.messages.SetChatWallPaper",
    0x92b4494c: "pyrogram.raw.functions.messages.SearchEmojiStickerSets",
    0x5381d21a: "pyrogram.raw.functions.messages.GetSavedDialogs",
    0x3d9a414d: "pyrogram.raw.functions.messages.GetSavedHistory",
    0x6e98102b: "pyrogram.raw.functions.messages.DeleteSavedHistory",
    0xd63d94e0: "pyrogram.raw.functions.messages.GetPinnedSavedDialogs",
    0xac81bbde: "pyrogram.raw.functions.messages.ToggleSavedDialogPin",
    0x8b716587: "pyrogram.raw.functions.messages.ReorderPinnedSavedDialogs",
    0x3637e05b: "pyrogram.raw.functions.messages.GetSavedReactionTags",
    0x60297dec: "pyrogram.raw.functions.messages.UpdateSavedReactionTag",
    0xbdf93428: "pyrogram.raw.functions.messages.GetDefaultTagReactions",
    0x8c4bfe5d: "pyrogram.raw.functions.messages.GetOutboxReadDate",
    0xd483f2a8: "pyrogram.raw.functions.messages.GetQuickReplies",
    0x60331907: "pyrogram.raw.functions.messages.ReorderQuickReplies",
    0xf1d0fbd3: "pyrogram.raw.functions.messages.CheckQuickReplyShortcut",
    0x5c003cef: "pyrogram.raw.functions.messages.EditQuickReplyShortcut",
    0x3cc04740: "pyrogram.raw.functions.messages.DeleteQuickReplyShortcut",
    0x94a495c3: "pyrogram.raw.functions.messages.GetQuickReplyMessages",
    0x6c750de1: "pyrogram.raw.functions.messages.SendQuickReplyMessages",
    0xe105e910: "pyrogram.raw.functions.messages.DeleteQuickReplyMessages",
    0xfd2dda49: "pyrogram.raw.functions.messages.ToggleDialogFilterTags",
    0xd0b5e1fc: "pyrogram.raw.functions.messages.GetMyStickers",
    0xedd4882a: "pyrogram.raw.functions.updates.GetState",
    0x19c2f763: "pyrogram.raw.functions.updates.GetDifference",
    0x3173d78: "pyrogram.raw.functions.updates.GetChannelDifference",
    0x9e82039: "pyrogram.raw.functions.photos.UpdateProfilePhoto",
    0x388a3b5: "pyrogram.raw.functions.photos.UploadProfilePhoto",
    0x87cf7f2f: "pyrogram.raw.functions.photos.DeletePhotos",
    0x91cd32a8: "pyrogram.raw.functions.photos.GetUserPhotos",
    0xe14c4a71: "pyrogram.raw.functions.photos.UploadContactProfilePhoto",
    0xb304a621: "pyrogram.raw.functions.upload.SaveFilePart",
    0xbe5335be: "pyrogram.raw.functions.upload.GetFile",
    0xde7b673d: "pyrogram.raw.functions.upload.SaveBigFilePart",
    0x24e6818d: "pyrogram.raw.functions.upload.GetWebFile",
    0x395f69da: "pyrogram.raw.functions.upload.GetCdnFile",
    0x9b2754a8: "pyrogram.raw.functions.upload.ReuploadCdnFile",
    0x91dc3f31: "pyrogram.raw.functions.upload.GetCdnFileHashes",
    0x9156982a: "pyrogram.raw.functions.upload.GetFileHashes",
    0xc4f9186b: "pyrogram.raw.functions.help.GetConfig",
    0x1fb33026: "pyrogram.raw.functions.help.GetNearestDc",
    0x522d5a7d: "pyrogram.raw.functions.help.GetAppUpdate",
    0x4d392343: "pyrogram.raw.functions.help.GetInviteText",
    0x9cdf08cd: "pyrogram.raw.functions.help.GetSupport",
    0xec22cfcd: "pyrogram.raw.functions.help.SetBotUpdatesStatus",
    0x52029342: "pyrogram.raw.functions.help.GetCdnConfig",
    0x3dc0f114: "pyrogram.raw.functions.help.GetRecentMeUrls",
    0x2ca51fd1: "pyrogram.raw.functions.help.GetTermsOfServiceUpdate",
    0xee72f79a: "pyrogram.raw.functions.help.AcceptTermsOfService",
    0x3fedc75f: "pyrogram.raw.functions.help.GetDeepLinkInfo",
    0x61e3f854: "pyrogram.raw.functions.help.GetAppConfig",
    0x6f02f748: "pyrogram.raw.functions.help.SaveAppLog",
    0xc661ad08: "pyrogram.raw.functions.help.GetPassportConfig",
    0xd360e72c: "pyrogram.raw.functions.help.GetSupportName",
    0x38a08d3: "pyrogram.raw.functions.help.GetUserInfo",
    0x66b91b70: "pyrogram.raw.functions.help.EditUserInfo",
    0xc0977421: "pyrogram.raw.functions.help.GetPromoData",
    0x1e251c95: "pyrogram.raw.functions.help.HidePromoData",
    0xf50dbaa1: "pyrogram.raw.functions.help.DismissSuggestion",
    0x735787a8: "pyrogram.raw.functions.help.GetCountriesList",
    0xb81b93d4: "pyrogram.raw.functions.help.GetPremiumPromo",
    0xda80f42f: "pyrogram.raw.functions.help.GetPeerColors",
    0xabcfa9fd: "pyrogram.raw.functions.help.GetPeerProfileColors",
    0x49b30240: "pyrogram.raw.functions.help.GetTimezonesList",
    0xcc104937: "pyrogram.raw.functions.channels.ReadHistory",
    0x84c1fd4e: "pyrogram.raw.functions.channels.DeleteMessages",
    0xf44a8315: "pyrogram.raw.functions.channels.ReportSpam",
    0xad8c9a23: "pyrogram.raw.functions.channels.GetMessages",
    0x77ced9d0: "pyrogram.raw.functions.channels.GetParticipants",
    0xa0ab6cc6: "pyrogram.raw.functions.channels.GetParticipant",
    0xa7f6bbb: "pyrogram.raw.functions.channels.GetChannels",
    0x8736a09: "pyrogram.raw.functions.channels.GetFullChannel",
    0x91006707: "pyrogram.raw.functions.channels.CreateChannel",
    0xd33c8902: "pyrogram.raw.functions.channels.EditAdmin",
    0x566decd0: "pyrogram.raw.functions.channels.EditTitle",
    0xf12e57c9: "pyrogram.raw.functions.channels.EditPhoto",
    0x10e6bd2c: "pyrogram.raw.functions.channels.CheckUsername",
    0x3514b3de: "pyrogram.raw.functions.channels.UpdateUsername",
    0x24b524c5: "pyrogram.raw.functions.channels.JoinChannel",
    0xf836aa95: "pyrogram.raw.functions.channels.LeaveChannel",
    0xc9e33d54: "pyrogram.raw.functions.channels.InviteToChannel",
    0xc0111fe3: "pyrogram.raw.functions.channels.DeleteChannel",
    0xe63fadeb: "pyrogram.raw.functions.channels.ExportMessageLink",
    0x1f69b606: "pyrogram.raw.functions.channels.ToggleSignatures",
    0xf8b036af: "pyrogram.raw.functions.channels.GetAdminedPublicChannels",
    0x96e6cd81: "pyrogram.raw.functions.channels.EditBanned",
    0x33ddf480: "pyrogram.raw.functions.channels.GetAdminLog",
    0xea8ca4f9: "pyrogram.raw.functions.channels.SetStickers",
    0xeab5dc38: "pyrogram.raw.functions.channels.ReadMessageContents",
    0x9baa9647: "pyrogram.raw.functions.channels.DeleteHistory",
    0xeabbb94c: "pyrogram.raw.functions.channels.TogglePreHistoryHidden",
    0x8341ecc0: "pyrogram.raw.functions.channels.GetLeftChannels",
    0xf5dad378: "pyrogram.raw.functions.channels.GetGroupsForDiscussion",
    0x40582bb2: "pyrogram.raw.functions.channels.SetDiscussionGroup",
    0x8f38cd1f: "pyrogram.raw.functions.channels.EditCreator",
    0x58e63f6d: "pyrogram.raw.functions.channels.EditLocation",
    0xedd49ef0: "pyrogram.raw.functions.channels.ToggleSlowMode",
    0x11e831ee: "pyrogram.raw.functions.channels.GetInactiveChannels",
    0xb290c69: "pyrogram.raw.functions.channels.ConvertToGigagroup",
    0xbeaedb94: "pyrogram.raw.functions.channels.ViewSponsoredMessage",
    0xec210fbf: "pyrogram.raw.functions.channels.GetSponsoredMessages",
    0xdc770ee: "pyrogram.raw.functions.channels.GetSendAs",
    0x367544db: "pyrogram.raw.functions.channels.DeleteParticipantHistory",
    0xe4cb9580: "pyrogram.raw.functions.channels.ToggleJoinToSend",
    0x4c2985b6: "pyrogram.raw.functions.channels.ToggleJoinRequest",
    0xb45ced1d: "pyrogram.raw.functions.channels.ReorderUsernames",
    0x50f24105: "pyrogram.raw.functions.channels.ToggleUsername",
    0xa245dd3: "pyrogram.raw.functions.channels.DeactivateAllUsernames",
    0xa4298b29: "pyrogram.raw.functions.channels.ToggleForum",
    0xf40c0224: "pyrogram.raw.functions.channels.CreateForumTopic",
    0xde560d1: "pyrogram.raw.functions.channels.GetForumTopics",
    0xb0831eb9: "pyrogram.raw.functions.channels.GetForumTopicsByID",
    0xf4dfa185: "pyrogram.raw.functions.channels.EditForumTopic",
    0x6c2d9026: "pyrogram.raw.functions.channels.UpdatePinnedForumTopic",
    0x34435f2d: "pyrogram.raw.functions.channels.DeleteTopicHistory",
    0x2950a18f: "pyrogram.raw.functions.channels.ReorderPinnedForumTopics",
    0x68f3e4eb: "pyrogram.raw.functions.channels.ToggleAntiSpam",
    0xa850a693: "pyrogram.raw.functions.channels.ReportAntiSpamFalsePositive",
    0x6a6e7854: "pyrogram.raw.functions.channels.ToggleParticipantsHidden",
    0x18afbc93: "pyrogram.raw.functions.channels.ClickSponsoredMessage",
    0xd8aa3671: "pyrogram.raw.functions.channels.UpdateColor",
    0x9738bb15: "pyrogram.raw.functions.channels.ToggleViewForumAsMessages",
    0x83b70d97: "pyrogram.raw.functions.channels.GetChannelRecommendations",
    0xf0d3e6a8: "pyrogram.raw.functions.channels.UpdateEmojiStatus",
    0xad399cee: "pyrogram.raw.functions.channels.SetBoostsToUnblockRestrictions",
    0x3cd930b7: "pyrogram.raw.functions.channels.SetEmojiStickers",
    0xaf8ff6b9: "pyrogram.raw.functions.channels.ReportSponsoredMessage",
    0x9ae91519: "pyrogram.raw.functions.channels.RestrictSponsoredMessages",
    0xaa2769ed: "pyrogram.raw.functions.bots.SendCustomRequest",
    0xe6213f4d: "pyrogram.raw.functions.bots.AnswerWebhookJSONQuery",
    0x517165a: "pyrogram.raw.functions.bots.SetBotCommands",
    0x3d8de0f9: "pyrogram.raw.functions.bots.ResetBotCommands",
    0xe34c0dd6: "pyrogram.raw.functions.bots.GetBotCommands",
    0x4504d54f: "pyrogram.raw.functions.bots.SetBotMenuButton",
    0x9c60eb28: "pyrogram.raw.functions.bots.GetBotMenuButton",
    0x788464e1: "pyrogram.raw.functions.bots.SetBotBroadcastDefaultAdminRights",
    0x925ec9ea: "pyrogram.raw.functions.bots.SetBotGroupDefaultAdminRights",
    0x10cf3123: "pyrogram.raw.functions.bots.SetBotInfo",
    0xdcd914fd: "pyrogram.raw.functions.bots.GetBotInfo",
    0x9709b1c2: "pyrogram.raw.functions.bots.ReorderUsernames",
    0x53ca973: "pyrogram.raw.functions.bots.ToggleUsername",
    0x1359f4e6: "pyrogram.raw.functions.bots.CanSendMessage",
    0xf132e3ef: "pyrogram.raw.functions.bots.AllowSendMessage",
    0x87fc5e7: "pyrogram.raw.functions.bots.InvokeWebViewCustomMethod",
    0x37148dbb: "pyrogram.raw.functions.payments.GetPaymentForm",
    0x2478d1cc: "pyrogram.raw.functions.payments.GetPaymentReceipt",
    0xb6c8f12b: "pyrogram.raw.functions.payments.ValidateRequestedInfo",
    0x2d03522f: "pyrogram.raw.functions.payments.SendPaymentForm",
    0x227d824b: "pyrogram.raw.functions.payments.GetSavedInfo",
    0xd83d70c1: "pyrogram.raw.functions.payments.ClearSavedInfo",
    0x2e79d779: "pyrogram.raw.functions.payments.GetBankCardData",
    0xf91b065: "pyrogram.raw.functions.payments.ExportInvoice",
    0x80ed747d: "pyrogram.raw.functions.payments.AssignAppStoreTransaction",
    0xdffd50d3: "pyrogram.raw.functions.payments.AssignPlayMarketTransaction",
    0x9fc19eb6: "pyrogram.raw.functions.payments.CanPurchasePremium",
    0x2757ba54: "pyrogram.raw.functions.payments.GetPremiumGiftCodeOptions",
    0x8e51b4c1: "pyrogram.raw.functions.payments.CheckGiftCode",
    0xf6e26854: "pyrogram.raw.functions.payments.ApplyGiftCode",
    0xf4239425: "pyrogram.raw.functions.payments.GetGiveawayInfo",
    0x5ff58f20: "pyrogram.raw.functions.payments.LaunchPrepaidGiveaway",
    0x9021ab67: "pyrogram.raw.functions.stickers.CreateStickerSet",
    0xf7760f51: "pyrogram.raw.functions.stickers.RemoveStickerFromSet",
    0xffb6d4ca: "pyrogram.raw.functions.stickers.ChangeStickerPosition",
    0x8653febe: "pyrogram.raw.functions.stickers.AddStickerToSet",
    0xa76a5392: "pyrogram.raw.functions.stickers.SetStickerSetThumb",
    0x284b3639: "pyrogram.raw.functions.stickers.CheckShortName",
    0x4dafc503: "pyrogram.raw.functions.stickers.SuggestShortName",
    0xf5537ebc: "pyrogram.raw.functions.stickers.ChangeSticker",
    0x124b1c00: "pyrogram.raw.functions.stickers.RenameStickerSet",
    0x87704394: "pyrogram.raw.functions.stickers.DeleteStickerSet",
    0x4696459a: "pyrogram.raw.functions.stickers.ReplaceSticker",
    0x55451fa9: "pyrogram.raw.functions.phone.GetCallConfig",
    0x42ff96ed: "pyrogram.raw.functions.phone.RequestCall",
    0x3bd2b4a0: "pyrogram.raw.functions.phone.AcceptCall",
    0x2efe1722: "pyrogram.raw.functions.phone.ConfirmCall",
    0x17d54f61: "pyrogram.raw.functions.phone.ReceivedCall",
    0xb2cbc1c0: "pyrogram.raw.functions.phone.DiscardCall",
    0x59ead627: "pyrogram.raw.functions.phone.SetCallRating",
    0x277add7e: "pyrogram.raw.functions.phone.SaveCallDebug",
    0xff7a9383: "pyrogram.raw.functions.phone.SendSignalingData",
    0x48cdc6d8: "pyrogram.raw.functions.phone.CreateGroupCall",
    0xb132ff7b: "pyrogram.raw.functions.phone.JoinGroupCall",
    0x500377f9: "pyrogram.raw.functions.phone.LeaveGroupCall",
    0x7b393160: "pyrogram.raw.functions.phone.InviteToGroupCall",
    0x7a777135: "pyrogram.raw.functions.phone.DiscardGroupCall",
    0x74bbb43d: "pyrogram.raw.functions.phone.ToggleGroupCallSettings",
    0x41845db: "pyrogram.raw.functions.phone.GetGroupCall",
    0xc558d8ab: "pyrogram.raw.functions.phone.GetGroupParticipants",
    0xb59cf977: "pyrogram.raw.functions.phone.CheckGroupCall",
    0xf128c708: "pyrogram.raw.functions.phone.ToggleGroupCallRecord",
    0xa5273abf: "pyrogram.raw.functions.phone.EditGroupCallParticipant",
    0x1ca6ac0a: "pyrogram.raw.functions.phone.EditGroupCallTitle",
    0xef7c213a: "pyrogram.raw.functions.phone.GetGroupCallJoinAs",
    0xe6aa647f: "pyrogram.raw.functions.phone.ExportGroupCallInvite",
    0x219c34e6: "pyrogram.raw.functions.phone.ToggleGroupCallStartSubscription",
    0x5680e342: "pyrogram.raw.functions.phone.StartScheduledGroupCall",
    0x575e1f8c: "pyrogram.raw.functions.phone.SaveDefaultGroupCallJoinAs",
    0xcbea6bc4: "pyrogram.raw.functions.phone.JoinGroupCallPresentation",
    0x1c50d144: "pyrogram.raw.functions.phone.LeaveGroupCallPresentation",
    0x1ab21940: "pyrogram.raw.functions.phone.GetGroupCallStreamChannels",
    0xdeb3abbf: "pyrogram.raw.functions.phone.GetGroupCallStreamRtmpUrl",
    0x41248786: "pyrogram.raw.functions.phone.SaveCallLog",
    0xf2f2330a: "pyrogram.raw.functions.langpack.GetLangPack",
    0xefea3803: "pyrogram.raw.functions.langpack.GetStrings",
    0xcd984aa5: "pyrogram.raw.functions.langpack.GetDifference",
    0x42c6978f: "pyrogram.raw.functions.langpack.GetLanguages",
    0x6a596502: "pyrogram.raw.functions.langpack.GetLanguage",
    0x6847d0ab: "pyrogram.raw.functions.folders.EditPeerFolders",
    0xab42441a: "pyrogram.raw.functions.stats.GetBroadcastStats",
    0x621d5fa0: "pyrogram.raw.functions.stats.LoadAsyncGraph",
    0xdcdf8607: "pyrogram.raw.functions.stats.GetMegagroupStats",
    0x5f150144: "pyrogram.raw.functions.stats.GetMessagePublicForwards",
    0xb6e0a3f5: "pyrogram.raw.functions.stats.GetMessageStats",
    0x374fef40: "pyrogram.raw.functions.stats.GetStoryStats",
    0xa6437ef6: "pyrogram.raw.functions.stats.GetStoryPublicForwards",
    0x75dfb671: "pyrogram.raw.functions.stats.GetBroadcastRevenueStats",
    0x2a65ef73: "pyrogram.raw.functions.stats.GetBroadcastRevenueWithdrawalUrl",
    0x69280f: "pyrogram.raw.functions.stats.GetBroadcastRevenueTransactions",
    0x8472478e: "pyrogram.raw.functions.chatlists.ExportChatlistInvite",
    0x719c5c5e: "pyrogram.raw.functions.chatlists.DeleteExportedInvite",
    0x653db63d: "pyrogram.raw.functions.chatlists.EditExportedInvite",
    0xce03da83: "pyrogram.raw.functions.chatlists.GetExportedInvites",
    0x41c10fff: "pyrogram.raw.functions.chatlists.CheckChatlistInvite",
    0xa6b1e39a: "pyrogram.raw.functions.chatlists.JoinChatlistInvite",
    0x89419521: "pyrogram.raw.functions.chatlists.GetChatlistUpdates",
    0xe089f8f5: "pyrogram.raw.functions.chatlists.JoinChatlistUpdates",
    0x66e486fb: "pyrogram.raw.functions.chatlists.HideChatlistUpdates",
    0xfdbcd714: "pyrogram.raw.functions.chatlists.GetLeaveChatlistSuggestions",
    0x74fae13a: "pyrogram.raw.functions.chatlists.LeaveChatlist",
    0xc7dfdfdd: "pyrogram.raw.functions.stories.CanSendStory",
    0xe4e6694b: "pyrogram.raw.functions.stories.SendStory",
    0xb583ba46: "pyrogram.raw.functions.stories.EditStory",
    0xae59db5f: "pyrogram.raw.functions.stories.DeleteStories",
    0x9a75a1ef: "pyrogram.raw.functions.stories.TogglePinned",
    0xeeb0d625: "pyrogram.raw.functions.stories.GetAllStories",
    0x5821a5dc: "pyrogram.raw.functions.stories.GetPinnedStories",
    0xb4352016: "pyrogram.raw.functions.stories.GetStoriesArchive",
    0x5774ca74: "pyrogram.raw.functions.stories.GetStoriesByID",
    0x7c2557c4: "pyrogram.raw.functions.stories.ToggleAllStoriesHidden",
    0xa556dac8: "pyrogram.raw.functions.stories.ReadStories",
    0xb2028afb: "pyrogram.raw.functions.stories.IncrementStoryViews",
    0x7ed23c57: "pyrogram.raw.functions.stories.GetStoryViewsList",
    0x28e16cc8: "pyrogram.raw.functions.stories.GetStoriesViews",
    0x7b8def20: "pyrogram.raw.functions.stories.ExportStoryLink",
    0x1923fa8c: "pyrogram.raw.functions.stories.Report",
    0x57bbd166: "pyrogram.raw.functions.stories.ActivateStealthMode",
    0x7fd736b2: "pyrogram.raw.functions.stories.SendReaction",
    0x2c4ada50: "pyrogram.raw.functions.stories.GetPeerStories",
    0x9b5ae7f9: "pyrogram.raw.functions.stories.GetAllReadPeerStories",
    0x535983c3: "pyrogram.raw.functions.stories.GetPeerMaxIDs",
    0xa56a8b60: "pyrogram.raw.functions.stories.GetChatsToSend",
    0xbd0415c4: "pyrogram.raw.functions.stories.TogglePeerStoriesHidden",
    0xb9b2881f: "pyrogram.raw.functions.stories.GetStoryReactionsList",
    0x60f67660: "pyrogram.raw.functions.premium.GetBoostsList",
    0xbe77b4a: "pyrogram.raw.functions.premium.GetMyBoosts",
    0x6b7da746: "pyrogram.raw.functions.premium.ApplyBoost",
    0x42f1f61: "pyrogram.raw.functions.premium.GetBoostsStatus",
    0x39854d1f: "pyrogram.raw.functions.premium.GetUserBoosts",
    0xedc39d0: "pyrogram.raw.functions.smsjobs.IsEligibleToJoin",
    0xa74ece2d: "pyrogram.raw.functions.smsjobs.Join",
    0x9898ad73: "pyrogram.raw.functions.smsjobs.Leave",
    0x93fa0bf: "pyrogram.raw.functions.smsjobs.UpdateSettings",
    0x10a698e8: "pyrogram.raw.functions.smsjobs.GetStatus",
    0x778d902f: "pyrogram.raw.functions.smsjobs.GetSmsJob",
    0x4f1ebf24: "pyrogram.raw.functions.smsjobs.FinishJob",
    0xbe1e85ba: "pyrogram.raw.functions.fragment.GetCollectibleInfo",
    0xbc799737: "pyrogram.raw.core.BoolFalse",
    0x997275b5: "pyrogram.raw.core.BoolTrue",
    0x1cb5c415: "pyrogram.raw.core.Vector",
    0x73f1f8dc: "pyrogram.raw.core.MsgContainer",
    0xae500895: "pyrogram.raw.core.FutureSalts",
    0x0949d9dc: "pyrogram.raw.core.FutureSalt",
    0x3072cfa1: "pyrogram.raw.core.GzipPacked",
    0x5bb8e511: "pyrogram.raw.core.Message",
}
